<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'kyss: vaksen, vaksen, hudtype 1–2, hudtype 3',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'kyss: vaksen, vaksen, hudtype 1–2, hudtype 4',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'kyss: vaksen, vaksen, hudtype 1–2, hudtype 5',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'kyss: vaksen, vaksen, hudtype 1–2, hudtype 6',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'kyss: vaksen, vaksen, hudtype 3, hudtype 1–2',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'kyss: vaksen, vaksen, hudtype 3, hudtype 4',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'kyss: vaksen, vaksen, hudtype 3, hudtype 5',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'kyss: vaksen, vaksen, hudtype 3, hudtype 6',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'kyss: vaksen, vaksen, hudtype 4, hudtype 1–2',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'kyss: vaksen, vaksen, hudtype 4, hudtype 3',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'kyss: vaksen, vaksen, hudtype 4, hudtype 5',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'kyss: vaksen, vaksen, hudtype 4, hudtype 6',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'kyss: vaksen, vaksen, hudtype 5, hudtype 1–2',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'kyss: vaksen, vaksen, hudtype 5, hudtype 3',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'kyss: vaksen, vaksen, hudtype 5, hudtype 4',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'kyss: vaksen, vaksen, hudtype 5, hudtype 6',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'kyss: vaksen, vaksen, hudtype 6, hudtype 1–2',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'kyss: vaksen, vaksen, hudtype 6, hudtype 3',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'kyss: vaksen, vaksen, hudtype 6, hudtype 4',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'kyss: vaksen, vaksen, hudtype 6, hudtype 5',
    '🧑🏻‍🫯‍🧑🏼' => 'brytarar: hudtype 1–2, hudtype 3',
    '🧑🏻‍🫯‍🧑🏽' => 'brytarar: hudtype 1–2, hudtype 4',
    '🧑🏻‍🫯‍🧑🏾' => 'brytarar: hudtype 1–2, hudtype 5',
    '🧑🏻‍🫯‍🧑🏿' => 'brytarar: hudtype 1–2, hudtype 6',
    '🧑🏼‍🫯‍🧑🏻' => 'brytarar: hudtype 3, hudtype 1–2',
    '🧑🏼‍🫯‍🧑🏽' => 'brytarar: hudtype 3, hudtype 4',
    '🧑🏼‍🫯‍🧑🏾' => 'brytarar: hudtype 3, hudtype 5',
    '🧑🏼‍🫯‍🧑🏿' => 'brytarar: hudtype 3, hudtype 6',
    '🧑🏽‍🫯‍🧑🏻' => 'brytarar: hudtype 4, hudtype 1–2',
    '🧑🏽‍🫯‍🧑🏼' => 'brytarar: hudtype 4, hudtype 3',
    '🧑🏽‍🫯‍🧑🏾' => 'brytarar: hudtype 4, hudtype 5',
    '🧑🏽‍🫯‍🧑🏿' => 'brytarar: hudtype 4, hudtype 6',
    '🧑🏾‍🫯‍🧑🏻' => 'brytarar: hudtype 5, hudtype 1–2',
    '🧑🏾‍🫯‍🧑🏼' => 'brytarar: hudtype 5, hudtype 3',
    '🧑🏾‍🫯‍🧑🏽' => 'brytarar: hudtype 5, hudtype 4',
    '🧑🏾‍🫯‍🧑🏿' => 'brytarar: hudtype 5, hudtype 6',
    '🧑🏿‍🫯‍🧑🏻' => 'brytarar: hudtype 6, hudtype 1–2',
    '🧑🏿‍🫯‍🧑🏼' => 'brytarar: hudtype 6, hudtype 3',
    '🧑🏿‍🫯‍🧑🏽' => 'brytarar: hudtype 6, hudtype 4',
    '🧑🏿‍🫯‍🧑🏾' => 'brytarar: hudtype 6, hudtype 5',
    '🧑🏻‍❤‍🧑🏼' => 'par med hjarte: vaksen, vaksen, hudtype 1–2, hudtype 3',
    '🧑🏻‍❤‍🧑🏽' => 'par med hjarte: vaksen, vaksen, hudtype 1–2, hudtype 4',
    '🧑🏻‍❤‍🧑🏾' => 'par med hjarte: vaksen, vaksen, hudtype 1–2, hudtype 5',
    '🧑🏻‍❤‍🧑🏿' => 'par med hjarte: vaksen, vaksen, hudtype 1–2, hudtype 6',
    '🧑🏼‍❤‍🧑🏻' => 'par med hjarte: vaksen, vaksen, hudtype 3, hudtype 1–2',
    '🧑🏼‍❤‍🧑🏽' => 'par med hjarte: vaksen, vaksen, hudtype 3, hudtype 4',
    '🧑🏼‍❤‍🧑🏾' => 'par med hjarte: vaksen, vaksen, hudtype 3, hudtype 5',
    '🧑🏼‍❤‍🧑🏿' => 'par med hjarte: vaksen, vaksen, hudtype 3, hudtype 6',
    '🧑🏽‍❤‍🧑🏻' => 'par med hjarte: vaksen, vaksen, hudtype 4, hudtype 1–2',
    '🧑🏽‍❤‍🧑🏼' => 'par med hjarte: vaksen, vaksen, hudtype 4, hudtype 3',
    '🧑🏽‍❤‍🧑🏾' => 'par med hjarte: vaksen, vaksen, hudtype 4, hudtype 5',
    '🧑🏽‍❤‍🧑🏿' => 'par med hjarte: vaksen, vaksen, hudtype 4, hudtype 6',
    '🧑🏾‍❤‍🧑🏻' => 'par med hjarte: vaksen, vaksen, hudtype 5, hudtype 1–2',
    '🧑🏾‍❤‍🧑🏼' => 'par med hjarte: vaksen, vaksen, hudtype 5, hudtype 3',
    '🧑🏾‍❤‍🧑🏽' => 'par med hjarte: vaksen, vaksen, hudtype 5, hudtype 4',
    '🧑🏾‍❤‍🧑🏿' => 'par med hjarte: vaksen, vaksen, hudtype 5, hudtype 6',
    '🧑🏿‍❤‍🧑🏻' => 'par med hjarte: vaksen, vaksen, hudtype 6, hudtype 1–2',
    '🧑🏿‍❤‍🧑🏼' => 'par med hjarte: vaksen, vaksen, hudtype 6, hudtype 3',
    '🧑🏿‍❤‍🧑🏽' => 'par med hjarte: vaksen, vaksen, hudtype 6, hudtype 4',
    '🧑🏿‍❤‍🧑🏾' => 'par med hjarte: vaksen, vaksen, hudtype 6, hudtype 5',
    '🧑🏻‍🐰‍🧑🏼' => 'personar med kaninøyre: hudtype 1–2, hudtype 3',
    '🧑🏻‍🐰‍🧑🏽' => 'personar med kaninøyre: hudtype 1–2, hudtype 4',
    '🧑🏻‍🐰‍🧑🏾' => 'personar med kaninøyre: hudtype 1–2, hudtype 5',
    '🧑🏻‍🐰‍🧑🏿' => 'personar med kaninøyre: hudtype 1–2, hudtype 6',
    '🧑🏼‍🐰‍🧑🏻' => 'personar med kaninøyre: hudtype 3, hudtype 1–2',
    '🧑🏼‍🐰‍🧑🏽' => 'personar med kaninøyre: hudtype 3, hudtype 4',
    '🧑🏼‍🐰‍🧑🏾' => 'personar med kaninøyre: hudtype 3, hudtype 5',
    '🧑🏼‍🐰‍🧑🏿' => 'personar med kaninøyre: hudtype 3, hudtype 6',
    '🧑🏽‍🐰‍🧑🏻' => 'personar med kaninøyre: hudtype 4, hudtype 1–2',
    '🧑🏽‍🐰‍🧑🏼' => 'personar med kaninøyre: hudtype 4, hudtype 3',
    '🧑🏽‍🐰‍🧑🏾' => 'personar med kaninøyre: hudtype 4, hudtype 5',
    '🧑🏽‍🐰‍🧑🏿' => 'personar med kaninøyre: hudtype 4, hudtype 6',
    '🧑🏾‍🐰‍🧑🏻' => 'personar med kaninøyre: hudtype 5, hudtype 1–2',
    '🧑🏾‍🐰‍🧑🏼' => 'personar med kaninøyre: hudtype 5, hudtype 3',
    '🧑🏾‍🐰‍🧑🏽' => 'personar med kaninøyre: hudtype 5, hudtype 4',
    '🧑🏾‍🐰‍🧑🏿' => 'personar med kaninøyre: hudtype 5, hudtype 6',
    '🧑🏿‍🐰‍🧑🏻' => 'personar med kaninøyre: hudtype 6, hudtype 1–2',
    '🧑🏿‍🐰‍🧑🏼' => 'personar med kaninøyre: hudtype 6, hudtype 3',
    '🧑🏿‍🐰‍🧑🏽' => 'personar med kaninøyre: hudtype 6, hudtype 4',
    '🧑🏿‍🐰‍🧑🏾' => 'personar med kaninøyre: hudtype 6, hudtype 5',
    '👨🏻‍🫯‍👨🏼' => 'mannlege brytarar: hudtype 1–2, hudtype 3',
    '👨🏻‍🫯‍👨🏽' => 'mannlege brytarar: hudtype 1–2, hudtype 4',
    '👨🏻‍🫯‍👨🏾' => 'mannlege brytarar: hudtype 1–2, hudtype 5',
    '👨🏻‍🫯‍👨🏿' => 'mannlege brytarar: hudtype 1–2, hudtype 6',
    '👨🏼‍🫯‍👨🏻' => 'mannlege brytarar: hudtype 3, hudtype 1–2',
    '👨🏼‍🫯‍👨🏽' => 'mannlege brytarar: hudtype 3, hudtype 4',
    '👨🏼‍🫯‍👨🏾' => 'mannlege brytarar: hudtype 3, hudtype 5',
    '👨🏼‍🫯‍👨🏿' => 'mannlege brytarar: hudtype 3, hudtype 6',
    '👨🏽‍🫯‍👨🏻' => 'mannlege brytarar: hudtype 4, hudtype 1–2',
    '👨🏽‍🫯‍👨🏼' => 'mannlege brytarar: hudtype 4, hudtype 3',
    '👨🏽‍🫯‍👨🏾' => 'mannlege brytarar: hudtype 4, hudtype 5',
    '👨🏽‍🫯‍👨🏿' => 'mannlege brytarar: hudtype 4, hudtype 6',
    '👨🏾‍🫯‍👨🏻' => 'mannlege brytarar: hudtype 5, hudtype 1–2',
    '👨🏾‍🫯‍👨🏼' => 'mannlege brytarar: hudtype 5, hudtype 3',
    '👨🏾‍🫯‍👨🏽' => 'mannlege brytarar: hudtype 5, hudtype 4',
    '👨🏾‍🫯‍👨🏿' => 'mannlege brytarar: hudtype 5, hudtype 6',
    '👨🏿‍🫯‍👨🏻' => 'mannlege brytarar: hudtype 6, hudtype 1–2',
    '👨🏿‍🫯‍👨🏼' => 'mannlege brytarar: hudtype 6, hudtype 3',
    '👨🏿‍🫯‍👨🏽' => 'mannlege brytarar: hudtype 6, hudtype 4',
    '👨🏿‍🫯‍👨🏾' => 'mannlege brytarar: hudtype 6, hudtype 5',
    '👨🏻‍❤‍👨🏻' => 'par med hjarte: mann, mann, hudtype 1–2',
    '👨🏻‍❤‍👨🏼' => 'par med hjarte: mann, mann, hudtype 1–2, hudtype 3',
    '👨🏻‍❤‍👨🏽' => 'par med hjarte: mann, mann, hudtype 1–2, hudtype 4',
    '👨🏻‍❤‍👨🏾' => 'par med hjarte: mann, mann, hudtype 1–2, hudtype 5',
    '👨🏻‍❤‍👨🏿' => 'par med hjarte: mann, mann, hudtype 1–2, hudtype 6',
    '👨🏼‍❤‍👨🏻' => 'par med hjarte: mann, mann, hudtype 3, hudtype 1–2',
    '👨🏼‍❤‍👨🏼' => 'par med hjarte: mann, mann, hudtype 3',
    '👨🏼‍❤‍👨🏽' => 'par med hjarte: mann, mann, hudtype 3, hudtype 4',
    '👨🏼‍❤‍👨🏾' => 'par med hjarte: mann, mann, hudtype 3, hudtype 5',
    '👨🏼‍❤‍👨🏿' => 'par med hjarte: mann, mann, hudtype 3, hudtype 6',
    '👨🏽‍❤‍👨🏻' => 'par med hjarte: mann, mann, hudtype 4, hudtype 1–2',
    '👨🏽‍❤‍👨🏼' => 'par med hjarte: mann, mann, hudtype 4, hudtype 3',
    '👨🏽‍❤‍👨🏽' => 'par med hjarte: mann, mann, hudtype 4',
    '👨🏽‍❤‍👨🏾' => 'par med hjarte: mann, mann, hudtype 4, hudtype 5',
    '👨🏽‍❤‍👨🏿' => 'par med hjarte: mann, mann, hudtype 4, hudtype 6',
    '👨🏾‍❤‍👨🏻' => 'par med hjarte: mann, mann, hudtype 5, hudtype 1–2',
    '👨🏾‍❤‍👨🏼' => 'par med hjarte: mann, mann, hudtype 5, hudtype 3',
    '👨🏾‍❤‍👨🏽' => 'par med hjarte: mann, mann, hudtype 5, hudtype 4',
    '👨🏾‍❤‍👨🏾' => 'par med hjarte: mann, mann, hudtype 5',
    '👨🏾‍❤‍👨🏿' => 'par med hjarte: mann, mann, hudtype 5, hudtype 6',
    '👨🏿‍❤‍👨🏻' => 'par med hjarte: mann, mann, hudtype 6, hudtype 1–2',
    '👨🏿‍❤‍👨🏼' => 'par med hjarte: mann, mann, hudtype 6, hudtype 3',
    '👨🏿‍❤‍👨🏽' => 'par med hjarte: mann, mann, hudtype 6, hudtype 4',
    '👨🏿‍❤‍👨🏾' => 'par med hjarte: mann, mann, hudtype 6, hudtype 5',
    '👨🏿‍❤‍👨🏿' => 'par med hjarte: mann, mann, hudtype 6',
    '👨🏻‍🐰‍👨🏼' => 'menn med kaninøyre: hudtype 1–2, hudtype 3',
    '👨🏻‍🐰‍👨🏽' => 'menn med kaninøyre: hudtype 1–2, hudtype 4',
    '👨🏻‍🐰‍👨🏾' => 'menn med kaninøyre: hudtype 1–2, hudtype 5',
    '👨🏻‍🐰‍👨🏿' => 'menn med kaninøyre: hudtype 1–2, hudtype 6',
    '👨🏼‍🐰‍👨🏻' => 'menn med kaninøyre: hudtype 3, hudtype 1–2',
    '👨🏼‍🐰‍👨🏽' => 'menn med kaninøyre: hudtype 3, hudtype 4',
    '👨🏼‍🐰‍👨🏾' => 'menn med kaninøyre: hudtype 3, hudtype 5',
    '👨🏼‍🐰‍👨🏿' => 'menn med kaninøyre: hudtype 3, hudtype 6',
    '👨🏽‍🐰‍👨🏻' => 'menn med kaninøyre: hudtype 4, hudtype 1–2',
    '👨🏽‍🐰‍👨🏼' => 'menn med kaninøyre: hudtype 4, hudtype 3',
    '👨🏽‍🐰‍👨🏾' => 'menn med kaninøyre: hudtype 4, hudtype 5',
    '👨🏽‍🐰‍👨🏿' => 'menn med kaninøyre: hudtype 4, hudtype 6',
    '👨🏾‍🐰‍👨🏻' => 'menn med kaninøyre: hudtype 5, hudtype 1–2',
    '👨🏾‍🐰‍👨🏼' => 'menn med kaninøyre: hudtype 5, hudtype 3',
    '👨🏾‍🐰‍👨🏽' => 'menn med kaninøyre: hudtype 5, hudtype 4',
    '👨🏾‍🐰‍👨🏿' => 'menn med kaninøyre: hudtype 5, hudtype 6',
    '👨🏿‍🐰‍👨🏻' => 'menn med kaninøyre: hudtype 6, hudtype 1–2',
    '👨🏿‍🐰‍👨🏼' => 'menn med kaninøyre: hudtype 6, hudtype 3',
    '👨🏿‍🐰‍👨🏽' => 'menn med kaninøyre: hudtype 6, hudtype 4',
    '👨🏿‍🐰‍👨🏾' => 'menn med kaninøyre: hudtype 6, hudtype 5',
    '👩🏻‍🫯‍👩🏼' => 'kvinnelege brytarar: hudtype 1–2, hudtype 3',
    '👩🏻‍🫯‍👩🏽' => 'kvinnelege brytarar: hudtype 1–2, hudtype 4',
    '👩🏻‍🫯‍👩🏾' => 'kvinnelege brytarar: hudtype 1–2, hudtype 5',
    '👩🏻‍🫯‍👩🏿' => 'kvinnelege brytarar: hudtype 1–2, hudtype 6',
    '👩🏼‍🫯‍👩🏻' => 'kvinnelege brytarar: hudtype 3, hudtype 1–2',
    '👩🏼‍🫯‍👩🏽' => 'kvinnelege brytarar: hudtype 3, hudtype 4',
    '👩🏼‍🫯‍👩🏾' => 'kvinnelege brytarar: hudtype 3, hudtype 5',
    '👩🏼‍🫯‍👩🏿' => 'kvinnelege brytarar: hudtype 3, hudtype 6',
    '👩🏽‍🫯‍👩🏻' => 'kvinnelege brytarar: hudtype 4, hudtype 1–2',
    '👩🏽‍🫯‍👩🏼' => 'kvinnelege brytarar: hudtype 4, hudtype 3',
    '👩🏽‍🫯‍👩🏾' => 'kvinnelege brytarar: hudtype 4, hudtype 5',
    '👩🏽‍🫯‍👩🏿' => 'kvinnelege brytarar: hudtype 4, hudtype 6',
    '👩🏾‍🫯‍👩🏻' => 'kvinnelege brytarar: hudtype 5, hudtype 1–2',
    '👩🏾‍🫯‍👩🏼' => 'kvinnelege brytarar: hudtype 5, hudtype 3',
    '👩🏾‍🫯‍👩🏽' => 'kvinnelege brytarar: hudtype 5, hudtype 4',
    '👩🏾‍🫯‍👩🏿' => 'kvinnelege brytarar: hudtype 5, hudtype 6',
    '👩🏿‍🫯‍👩🏻' => 'kvinnelege brytarar: hudtype 6, hudtype 1–2',
    '👩🏿‍🫯‍👩🏼' => 'kvinnelege brytarar: hudtype 6, hudtype 3',
    '👩🏿‍🫯‍👩🏽' => 'kvinnelege brytarar: hudtype 6, hudtype 4',
    '👩🏿‍🫯‍👩🏾' => 'kvinnelege brytarar: hudtype 6, hudtype 5',
    '👩🏻‍❤‍👨🏻' => 'par med hjarte: kvinne, mann, hudtype 1–2',
    '👩🏻‍❤‍👨🏼' => 'par med hjarte: kvinne, mann, hudtype 1–2, hudtype 3',
    '👩🏻‍❤‍👨🏽' => 'par med hjarte: kvinne, mann, hudtype 1–2, hudtype 4',
    '👩🏻‍❤‍👨🏾' => 'par med hjarte: kvinne, mann, hudtype 1–2, hudtype 5',
    '👩🏻‍❤‍👨🏿' => 'par med hjarte: kvinne, mann, hudtype 1–2, hudtype 6',
    '👩🏼‍❤‍👨🏻' => 'par med hjarte: kvinne, mann, hudtype 3, hudtype 1–2',
    '👩🏼‍❤‍👨🏼' => 'par med hjarte: kvinne, mann, hudtype 3',
    '👩🏼‍❤‍👨🏽' => 'par med hjarte: kvinne, mann, hudtype 3, hudtype 4',
    '👩🏼‍❤‍👨🏾' => 'par med hjarte: kvinne, mann, hudtype 3, hudtype 5',
    '👩🏼‍❤‍👨🏿' => 'par med hjarte: kvinne, mann, hudtype 3, hudtype 6',
    '👩🏽‍❤‍👨🏻' => 'par med hjarte: kvinne, mann, hudtype 4, hudtype 1–2',
    '👩🏽‍❤‍👨🏼' => 'par med hjarte: kvinne, mann, hudtype 4, hudtype 3',
    '👩🏽‍❤‍👨🏽' => 'par med hjarte: kvinne, mann, hudtype 4',
    '👩🏽‍❤‍👨🏾' => 'par med hjarte: kvinne, mann, hudtype 4, hudtype 5',
    '👩🏽‍❤‍👨🏿' => 'par med hjarte: kvinne, mann, hudtype 4, hudtype 6',
    '👩🏾‍❤‍👨🏻' => 'par med hjarte: kvinne, mann, hudtype 5, hudtype 1–2',
    '👩🏾‍❤‍👨🏼' => 'par med hjarte: kvinne, mann, hudtype 5, hudtype 3',
    '👩🏾‍❤‍👨🏽' => 'par med hjarte: kvinne, mann, hudtype 5, hudtype 4',
    '👩🏾‍❤‍👨🏾' => 'par med hjarte: kvinne, mann, hudtype 5',
    '👩🏾‍❤‍👨🏿' => 'par med hjarte: kvinne, mann, hudtype 5, hudtype 6',
    '👩🏿‍❤‍👨🏻' => 'par med hjarte: kvinne, mann, hudtype 6, hudtype 1–2',
    '👩🏿‍❤‍👨🏼' => 'par med hjarte: kvinne, mann, hudtype 6, hudtype 3',
    '👩🏿‍❤‍👨🏽' => 'par med hjarte: kvinne, mann, hudtype 6, hudtype 4',
    '👩🏿‍❤‍👨🏾' => 'par med hjarte: kvinne, mann, hudtype 6, hudtype 5',
    '👩🏿‍❤‍👨🏿' => 'par med hjarte: kvinne, mann, hudtype 6',
    '👩🏻‍❤‍👩🏻' => 'par med hjarte: kvinne, kvinne, hudtype 1–2',
    '👩🏻‍❤‍👩🏼' => 'par med hjarte: kvinne, kvinne, hudtype 1–2, hudtype 3',
    '👩🏻‍❤‍👩🏽' => 'par med hjarte: kvinne, kvinne, hudtype 1–2, hudtype 4',
    '👩🏻‍❤‍👩🏾' => 'par med hjarte: kvinne, kvinne, hudtype 1–2, hudtype 5',
    '👩🏻‍❤‍👩🏿' => 'par med hjarte: kvinne, kvinne, hudtype 1–2, hudtype 6',
    '👩🏼‍❤‍👩🏻' => 'par med hjarte: kvinne, kvinne, hudtype 3, hudtype 1–2',
    '👩🏼‍❤‍👩🏼' => 'par med hjarte: kvinne, kvinne, hudtype 3',
    '👩🏼‍❤‍👩🏽' => 'par med hjarte: kvinne, kvinne, hudtype 3, hudtype 4',
    '👩🏼‍❤‍👩🏾' => 'par med hjarte: kvinne, kvinne, hudtype 3, hudtype 5',
    '👩🏼‍❤‍👩🏿' => 'par med hjarte: kvinne, kvinne, hudtype 3, hudtype 6',
    '👩🏽‍❤‍👩🏻' => 'par med hjarte: kvinne, kvinne, hudtype 4, hudtype 1–2',
    '👩🏽‍❤‍👩🏼' => 'par med hjarte: kvinne, kvinne, hudtype 4, hudtype 3',
    '👩🏽‍❤‍👩🏽' => 'par med hjarte: kvinne, kvinne, hudtype 4',
    '👩🏽‍❤‍👩🏾' => 'par med hjarte: kvinne, kvinne, hudtype 4, hudtype 5',
    '👩🏽‍❤‍👩🏿' => 'par med hjarte: kvinne, kvinne, hudtype 4, hudtype 6',
    '👩🏾‍❤‍👩🏻' => 'par med hjarte: kvinne, kvinne, hudtype 5, hudtype 1–2',
    '👩🏾‍❤‍👩🏼' => 'par med hjarte: kvinne, kvinne, hudtype 5, hudtype 3',
    '👩🏾‍❤‍👩🏽' => 'par med hjarte: kvinne, kvinne, hudtype 5, hudtype 4',
    '👩🏾‍❤‍👩🏾' => 'par med hjarte: kvinne, kvinne, hudtype 5',
    '👩🏾‍❤‍👩🏿' => 'par med hjarte: kvinne, kvinne, hudtype 5, hudtype 6',
    '👩🏿‍❤‍👩🏻' => 'par med hjarte: kvinne, kvinne, hudtype 6, hudtype 1–2',
    '👩🏿‍❤‍👩🏼' => 'par med hjarte: kvinne, kvinne, hudtype 6, hudtype 3',
    '👩🏿‍❤‍👩🏽' => 'par med hjarte: kvinne, kvinne, hudtype 6, hudtype 4',
    '👩🏿‍❤‍👩🏾' => 'par med hjarte: kvinne, kvinne, hudtype 6, hudtype 5',
    '👩🏿‍❤‍👩🏿' => 'par med hjarte: kvinne, kvinne, hudtype 6',
    '👩🏻‍🐰‍👩🏼' => 'kvinner med kaninøyre: hudtype 1–2, hudtype 3',
    '👩🏻‍🐰‍👩🏽' => 'kvinner med kaninøyre: hudtype 1–2, hudtype 4',
    '👩🏻‍🐰‍👩🏾' => 'kvinner med kaninøyre: hudtype 1–2, hudtype 5',
    '👩🏻‍🐰‍👩🏿' => 'kvinner med kaninøyre: hudtype 1–2, hudtype 6',
    '👩🏼‍🐰‍👩🏻' => 'kvinner med kaninøyre: hudtype 3, hudtype 1–2',
    '👩🏼‍🐰‍👩🏽' => 'kvinner med kaninøyre: hudtype 3, hudtype 4',
    '👩🏼‍🐰‍👩🏾' => 'kvinner med kaninøyre: hudtype 3, hudtype 5',
    '👩🏼‍🐰‍👩🏿' => 'kvinner med kaninøyre: hudtype 3, hudtype 6',
    '👩🏽‍🐰‍👩🏻' => 'kvinner med kaninøyre: hudtype 4, hudtype 1–2',
    '👩🏽‍🐰‍👩🏼' => 'kvinner med kaninøyre: hudtype 4, hudtype 3',
    '👩🏽‍🐰‍👩🏾' => 'kvinner med kaninøyre: hudtype 4, hudtype 5',
    '👩🏽‍🐰‍👩🏿' => 'kvinner med kaninøyre: hudtype 4, hudtype 6',
    '👩🏾‍🐰‍👩🏻' => 'kvinner med kaninøyre: hudtype 5, hudtype 1–2',
    '👩🏾‍🐰‍👩🏼' => 'kvinner med kaninøyre: hudtype 5, hudtype 3',
    '👩🏾‍🐰‍👩🏽' => 'kvinner med kaninøyre: hudtype 5, hudtype 4',
    '👩🏾‍🐰‍👩🏿' => 'kvinner med kaninøyre: hudtype 5, hudtype 6',
    '👩🏿‍🐰‍👩🏻' => 'kvinner med kaninøyre: hudtype 6, hudtype 1–2',
    '👩🏿‍🐰‍👩🏼' => 'kvinner med kaninøyre: hudtype 6, hudtype 3',
    '👩🏿‍🐰‍👩🏽' => 'kvinner med kaninøyre: hudtype 6, hudtype 4',
    '👩🏿‍🐰‍👩🏾' => 'kvinner med kaninøyre: hudtype 6, hudtype 5',
    '🧑🏻‍🤝‍🧑🏻' => 'personar som leiar: hudtype 1–2',
    '🧑🏻‍🤝‍🧑🏼' => 'personar som leiar: hudtype 1–2, hudtype 3',
    '🧑🏻‍🤝‍🧑🏽' => 'personar som leiar: hudtype 1–2, hudtype 4',
    '🧑🏻‍🤝‍🧑🏾' => 'personar som leiar: hudtype 1–2, hudtype 5',
    '🧑🏻‍🤝‍🧑🏿' => 'personar som leiar: hudtype 1–2, hudtype 6',
    '🧑🏼‍🤝‍🧑🏻' => 'personar som leiar: hudtype 3, hudtype 1–2',
    '🧑🏼‍🤝‍🧑🏼' => 'personar som leiar: hudtype 3',
    '🧑🏼‍🤝‍🧑🏽' => 'personar som leiar: hudtype 3, hudtype 4',
    '🧑🏼‍🤝‍🧑🏾' => 'personar som leiar: hudtype 3, hudtype 5',
    '🧑🏼‍🤝‍🧑🏿' => 'personar som leiar: hudtype 3, hudtype 6',
    '🧑🏽‍🤝‍🧑🏻' => 'personar som leiar: hudtype 4, hudtype 1–2',
    '🧑🏽‍🤝‍🧑🏼' => 'personar som leiar: hudtype 4, hudtype 3',
    '🧑🏽‍🤝‍🧑🏽' => 'personar som leiar: hudtype 4',
    '🧑🏽‍🤝‍🧑🏾' => 'personar som leiar: hudtype 4, hudtype 5',
    '🧑🏽‍🤝‍🧑🏿' => 'personar som leiar: hudtype 4, hudtype 6',
    '🧑🏾‍🤝‍🧑🏻' => 'personar som leiar: hudtype 5, hudtype 1–2',
    '🧑🏾‍🤝‍🧑🏼' => 'personar som leiar: hudtype 5, hudtype 3',
    '🧑🏾‍🤝‍🧑🏽' => 'personar som leiar: hudtype 5, hudtype 4',
    '🧑🏾‍🤝‍🧑🏾' => 'personar som leiar: hudtype 5',
    '🧑🏾‍🤝‍🧑🏿' => 'personar som leiar: hudtype 5, hudtype 6',
    '🧑🏿‍🤝‍🧑🏻' => 'personar som leiar: hudtype 6, hudtype 1–2',
    '🧑🏿‍🤝‍🧑🏼' => 'personar som leiar: hudtype 6, hudtype 3',
    '🧑🏿‍🤝‍🧑🏽' => 'personar som leiar: hudtype 6, hudtype 4',
    '🧑🏿‍🤝‍🧑🏾' => 'personar som leiar: hudtype 6, hudtype 5',
    '🧑🏿‍🤝‍🧑🏿' => 'personar som leiar: hudtype 6',
    '👩🏻‍🤝‍👩🏼' => 'kvinner som leiar: hudtype 1–2, hudtype 3',
    '👩🏻‍🤝‍👩🏽' => 'kvinner som leiar: hudtype 1–2, hudtype 4',
    '👩🏻‍🤝‍👩🏾' => 'kvinner som leiar: hudtype 1–2, hudtype 5',
    '👩🏻‍🤝‍👩🏿' => 'kvinner som leiar: hudtype 1–2, hudtype 6',
    '👩🏼‍🤝‍👩🏻' => 'kvinner som leiar: hudtype 3, hudtype 1–2',
    '👩🏼‍🤝‍👩🏽' => 'kvinner som leiar: hudtype 3, hudtype 4',
    '👩🏼‍🤝‍👩🏾' => 'kvinner som leiar: hudtype 3, hudtype 5',
    '👩🏼‍🤝‍👩🏿' => 'kvinner som leiar: hudtype 3, hudtype 6',
    '👩🏽‍🤝‍👩🏻' => 'kvinner som leiar: hudtype 4, hudtype 1–2',
    '👩🏽‍🤝‍👩🏼' => 'kvinner som leiar: hudtype 4, hudtype 3',
    '👩🏽‍🤝‍👩🏾' => 'kvinner som leiar: hudtype 4, hudtype 5',
    '👩🏽‍🤝‍👩🏿' => 'kvinner som leiar: hudtype 4, hudtype 6',
    '👩🏾‍🤝‍👩🏻' => 'kvinner som leiar: hudtype 5, hudtype 1–2',
    '👩🏾‍🤝‍👩🏼' => 'kvinner som leiar: hudtype 5, hudtype 3',
    '👩🏾‍🤝‍👩🏽' => 'kvinner som leiar: hudtype 5, hudtype 4',
    '👩🏾‍🤝‍👩🏿' => 'kvinner som leiar: hudtype 5, hudtype 6',
    '👩🏿‍🤝‍👩🏻' => 'kvinner som leiar: hudtype 6, hudtype 1–2',
    '👩🏿‍🤝‍👩🏼' => 'kvinner som leiar: hudtype 6, hudtype 3',
    '👩🏿‍🤝‍👩🏽' => 'kvinner som leiar: hudtype 6, hudtype 4',
    '👩🏿‍🤝‍👩🏾' => 'kvinner som leiar: hudtype 6, hudtype 5',
    '👩🏻‍🤝‍👨🏼' => 'mann og kvinne som leiar: hudtype 1–2, hudtype 3',
    '👩🏻‍🤝‍👨🏽' => 'mann og kvinne som leiar: hudtype 1–2, hudtype 4',
    '👩🏻‍🤝‍👨🏾' => 'mann og kvinne som leiar: hudtype 1–2, hudtype 5',
    '👩🏻‍🤝‍👨🏿' => 'mann og kvinne som leiar: hudtype 1–2, hudtype 6',
    '👩🏼‍🤝‍👨🏻' => 'mann og kvinne som leiar: hudtype 3, hudtype 1–2',
    '👩🏼‍🤝‍👨🏽' => 'mann og kvinne som leiar: hudtype 3, hudtype 4',
    '👩🏼‍🤝‍👨🏾' => 'mann og kvinne som leiar: hudtype 3, hudtype 5',
    '👩🏼‍🤝‍👨🏿' => 'mann og kvinne som leiar: hudtype 3, hudtype 6',
    '👩🏽‍🤝‍👨🏻' => 'mann og kvinne som leiar: hudtype 4, hudtype 1–2',
    '👩🏽‍🤝‍👨🏼' => 'mann og kvinne som leiar: hudtype 4, hudtype 3',
    '👩🏽‍🤝‍👨🏾' => 'mann og kvinne som leiar: hudtype 4, hudtype 5',
    '👩🏽‍🤝‍👨🏿' => 'mann og kvinne som leiar: hudtype 4, hudtype 6',
    '👩🏾‍🤝‍👨🏻' => 'mann og kvinne som leiar: hudtype 5, hudtype 1–2',
    '👩🏾‍🤝‍👨🏼' => 'mann og kvinne som leiar: hudtype 5, hudtype 3',
    '👩🏾‍🤝‍👨🏽' => 'mann og kvinne som leiar: hudtype 5, hudtype 4',
    '👩🏾‍🤝‍👨🏿' => 'mann og kvinne som leiar: hudtype 5, hudtype 6',
    '👩🏿‍🤝‍👨🏻' => 'mann og kvinne som leiar: hudtype 6, hudtype 1–2',
    '👩🏿‍🤝‍👨🏼' => 'mann og kvinne som leiar: hudtype 6, hudtype 3',
    '👩🏿‍🤝‍👨🏽' => 'mann og kvinne som leiar: hudtype 6, hudtype 4',
    '👩🏿‍🤝‍👨🏾' => 'mann og kvinne som leiar: hudtype 6, hudtype 5',
    '👨🏻‍🤝‍👨🏼' => 'menn som leiar: hudtype 1–2, hudtype 3',
    '👨🏻‍🤝‍👨🏽' => 'menn som leiar: hudtype 1–2, hudtype 4',
    '👨🏻‍🤝‍👨🏾' => 'menn som leiar: hudtype 1–2, hudtype 5',
    '👨🏻‍🤝‍👨🏿' => 'menn som leiar: hudtype 1–2, hudtype 6',
    '👨🏼‍🤝‍👨🏻' => 'menn som leiar: hudtype 3, hudtype 1–2',
    '👨🏼‍🤝‍👨🏽' => 'menn som leiar: hudtype 3, hudtype 4',
    '👨🏼‍🤝‍👨🏾' => 'menn som leiar: hudtype 3, hudtype 5',
    '👨🏼‍🤝‍👨🏿' => 'menn som leiar: hudtype 3, hudtype 6',
    '👨🏽‍🤝‍👨🏻' => 'menn som leiar: hudtype 4, hudtype 1–2',
    '👨🏽‍🤝‍👨🏼' => 'menn som leiar: hudtype 4, hudtype 3',
    '👨🏽‍🤝‍👨🏾' => 'menn som leiar: hudtype 4, hudtype 5',
    '👨🏽‍🤝‍👨🏿' => 'menn som leiar: hudtype 4, hudtype 6',
    '👨🏾‍🤝‍👨🏻' => 'menn som leiar: hudtype 5, hudtype 1–2',
    '👨🏾‍🤝‍👨🏼' => 'menn som leiar: hudtype 5, hudtype 3',
    '👨🏾‍🤝‍👨🏽' => 'menn som leiar: hudtype 5, hudtype 4',
    '👨🏾‍🤝‍👨🏿' => 'menn som leiar: hudtype 5, hudtype 6',
    '👨🏿‍🤝‍👨🏻' => 'menn som leiar: hudtype 6, hudtype 1–2',
    '👨🏿‍🤝‍👨🏼' => 'menn som leiar: hudtype 6, hudtype 3',
    '👨🏿‍🤝‍👨🏽' => 'menn som leiar: hudtype 6, hudtype 4',
    '👨🏿‍🤝‍👨🏾' => 'menn som leiar: hudtype 6, hudtype 5',
    '👨‍👩‍👧‍👦' => 'familie: mann, kvinne, jente, gut',
    '👨‍👩‍👦‍👦' => 'familie: mann, kvinne, gut, gut',
    '👨‍👨‍👧‍👦' => 'familie: mann, mann, jente, gut',
    '👨‍👨‍👦‍👦' => 'familie: mann, mann, gut, gut',
    '👩‍👩‍👧‍👦' => 'familie: kvinne, kvinne, jente, gut',
    '👩‍👩‍👦‍👦' => 'familie: kvinne, kvinne, gut, gut',
    '🧑‍🧑‍🧒‍🧒' => 'familie: vaksen, vaksen, barn, barn',
    '🚶🏻‍♀‍➡' => 'kvinneleg fotgjengar: hudtype 1–2, vendt mot høgre',
    '🚶🏼‍♀‍➡' => 'kvinneleg fotgjengar: hudtype 3, vendt mot høgre',
    '🚶🏽‍♀‍➡' => 'kvinneleg fotgjengar: hudtype 4, vendt mot høgre',
    '🚶🏾‍♀‍➡' => 'kvinneleg fotgjengar: hudtype 5, vendt mot høgre',
    '🚶🏿‍♀‍➡' => 'kvinneleg fotgjengar: hudtype 6, vendt mot høgre',
    '🚶🏻‍♂‍➡' => 'mannleg fotgjengar: hudtype 1–2, vendt mot høgre',
    '🚶🏼‍♂‍➡' => 'mannleg fotgjengar: hudtype 3, vendt mot høgre',
    '🚶🏽‍♂‍➡' => 'mannleg fotgjengar: hudtype 4, vendt mot høgre',
    '🚶🏾‍♂‍➡' => 'mannleg fotgjengar: hudtype 5, vendt mot høgre',
    '🚶🏿‍♂‍➡' => 'mannleg fotgjengar: hudtype 6, vendt mot høgre',
    '🧎🏻‍♀‍➡' => 'kvinne som kneler: hudtype 1–2, vendt mot høgre',
    '🧎🏼‍♀‍➡' => 'kvinne som kneler: hudtype 3, vendt mot høgre',
    '🧎🏽‍♀‍➡' => 'kvinne som kneler: hudtype 4, vendt mot høgre',
    '🧎🏾‍♀‍➡' => 'kvinne som kneler: hudtype 5, vendt mot høgre',
    '🧎🏿‍♀‍➡' => 'kvinne som kneler: hudtype 6, vendt mot høgre',
    '🧎🏻‍♂‍➡' => 'mann som kneler: hudtype 1–2, vendt mot høgre',
    '🧎🏼‍♂‍➡' => 'mann som kneler: hudtype 3, vendt mot høgre',
    '🧎🏽‍♂‍➡' => 'mann som kneler: hudtype 4, vendt mot høgre',
    '🧎🏾‍♂‍➡' => 'mann som kneler: hudtype 5, vendt mot høgre',
    '🧎🏿‍♂‍➡' => 'mann som kneler: hudtype 6, vendt mot høgre',
    '🧑🏻‍🦯‍➡' => 'person med blindestokk: hudtype 1–2, vendt mot høgre',
    '🧑🏼‍🦯‍➡' => 'person med blindestokk: hudtype 3, vendt mot høgre',
    '🧑🏽‍🦯‍➡' => 'person med blindestokk: hudtype 4, vendt mot høgre',
    '🧑🏾‍🦯‍➡' => 'person med blindestokk: hudtype 5, vendt mot høgre',
    '🧑🏿‍🦯‍➡' => 'person med blindestokk: hudtype 6, vendt mot høgre',
    '👨🏻‍🦯‍➡' => 'mann med blindestokk: hudtype 1–2, vendt mot høgre',
    '👨🏼‍🦯‍➡' => 'mann med blindestokk: hudtype 3, vendt mot høgre',
    '👨🏽‍🦯‍➡' => 'mann med blindestokk: hudtype 4, vendt mot høgre',
    '👨🏾‍🦯‍➡' => 'mann med blindestokk: hudtype 5, vendt mot høgre',
    '👨🏿‍🦯‍➡' => 'mann med blindestokk: hudtype 6, vendt mot høgre',
    '👩🏻‍🦯‍➡' => 'kvinne med blindestokk: hudtype 1–2, vendt mot høgre',
    '👩🏼‍🦯‍➡' => 'kvinne med blindestokk: hudtype 3, vendt mot høgre',
    '👩🏽‍🦯‍➡' => 'kvinne med blindestokk: hudtype 4, vendt mot høgre',
    '👩🏾‍🦯‍➡' => 'kvinne med blindestokk: hudtype 5, vendt mot høgre',
    '👩🏿‍🦯‍➡' => 'kvinne med blindestokk: hudtype 6, vendt mot høgre',
    '🧑🏻‍🦼‍➡' => 'person i motorisert rullestol: hudtype 1–2, vendt mot høgre',
    '🧑🏼‍🦼‍➡' => 'person i motorisert rullestol: hudtype 3, vendt mot høgre',
    '🧑🏽‍🦼‍➡' => 'person i motorisert rullestol: hudtype 4, vendt mot høgre',
    '🧑🏾‍🦼‍➡' => 'person i motorisert rullestol: hudtype 5, vendt mot høgre',
    '🧑🏿‍🦼‍➡' => 'person i motorisert rullestol: hudtype 6, vendt mot høgre',
    '👨🏻‍🦼‍➡' => 'mann i motorisert rullestol: hudtype 1–2, vendt mot høgre',
    '👨🏼‍🦼‍➡' => 'mann i motorisert rullestol: hudtype 3, vendt mot høgre',
    '👨🏽‍🦼‍➡' => 'mann i motorisert rullestol: hudtype 4, vendt mot høgre',
    '👨🏾‍🦼‍➡' => 'mann i motorisert rullestol: hudtype 5, vendt mot høgre',
    '👨🏿‍🦼‍➡' => 'mann i motorisert rullestol: hudtype 6, vendt mot høgre',
    '👩🏻‍🦼‍➡' => 'kvinne i motorisert rullestol: hudtype 1–2, vendt mot høgre',
    '👩🏼‍🦼‍➡' => 'kvinne i motorisert rullestol: hudtype 3, vendt mot høgre',
    '👩🏽‍🦼‍➡' => 'kvinne i motorisert rullestol: hudtype 4, vendt mot høgre',
    '👩🏾‍🦼‍➡' => 'kvinne i motorisert rullestol: hudtype 5, vendt mot høgre',
    '👩🏿‍🦼‍➡' => 'kvinne i motorisert rullestol: hudtype 6, vendt mot høgre',
    '🧑🏻‍🦽‍➡' => 'person i manuell rullestol: hudtype 1–2, vendt mot høgre',
    '🧑🏼‍🦽‍➡' => 'person i manuell rullestol: hudtype 3, vendt mot høgre',
    '🧑🏽‍🦽‍➡' => 'person i manuell rullestol: hudtype 4, vendt mot høgre',
    '🧑🏾‍🦽‍➡' => 'person i manuell rullestol: hudtype 5, vendt mot høgre',
    '🧑🏿‍🦽‍➡' => 'person i manuell rullestol: hudtype 6, vendt mot høgre',
    '👨🏻‍🦽‍➡' => 'mann i manuell rullestol: hudtype 1–2, vendt mot høgre',
    '👨🏼‍🦽‍➡' => 'mann i manuell rullestol: hudtype 3, vendt mot høgre',
    '👨🏽‍🦽‍➡' => 'mann i manuell rullestol: hudtype 4, vendt mot høgre',
    '👨🏾‍🦽‍➡' => 'mann i manuell rullestol: hudtype 5, vendt mot høgre',
    '👨🏿‍🦽‍➡' => 'mann i manuell rullestol: hudtype 6, vendt mot høgre',
    '👩🏻‍🦽‍➡' => 'kvinne i manuell rullestol: hudtype 1–2, vendt mot høgre',
    '👩🏼‍🦽‍➡' => 'kvinne i manuell rullestol: hudtype 3, vendt mot høgre',
    '👩🏽‍🦽‍➡' => 'kvinne i manuell rullestol: hudtype 4, vendt mot høgre',
    '👩🏾‍🦽‍➡' => 'kvinne i manuell rullestol: hudtype 5, vendt mot høgre',
    '👩🏿‍🦽‍➡' => 'kvinne i manuell rullestol: hudtype 6, vendt mot høgre',
    '🏃🏻‍♀‍➡' => 'kvineleg løpar: hudtype 1–2, vendt mot høgre',
    '🏃🏼‍♀‍➡' => 'kvineleg løpar: hudtype 3, vendt mot høgre',
    '🏃🏽‍♀‍➡' => 'kvineleg løpar: hudtype 4, vendt mot høgre',
    '🏃🏾‍♀‍➡' => 'kvineleg løpar: hudtype 5, vendt mot høgre',
    '🏃🏿‍♀‍➡' => 'kvineleg løpar: hudtype 6, vendt mot høgre',
    '🏃🏻‍♂‍➡' => 'mannleg løpar: hudtype 1–2, vendt mot høgre',
    '🏃🏼‍♂‍➡' => 'mannleg løpar: hudtype 3, vendt mot høgre',
    '🏃🏽‍♂‍➡' => 'mannleg løpar: hudtype 4, vendt mot høgre',
    '🏃🏾‍♂‍➡' => 'mannleg løpar: hudtype 5, vendt mot høgre',
    '🏃🏿‍♂‍➡' => 'mannleg løpar: hudtype 6, vendt mot høgre',
    '🫱🏻‍🫲🏼' => 'handhelse: hudtype 1–2, hudtype 3',
    '🫱🏻‍🫲🏽' => 'handhelse: hudtype 1–2, hudtype 4',
    '🫱🏻‍🫲🏾' => 'handhelse: hudtype 1–2, hudtype 5',
    '🫱🏻‍🫲🏿' => 'handhelse: hudtype 1–2, hudtype 6',
    '🫱🏼‍🫲🏻' => 'handhelse: hudtype 3, hudtype 1–2',
    '🫱🏼‍🫲🏽' => 'handhelse: hudtype 3, hudtype 4',
    '🫱🏼‍🫲🏾' => 'handhelse: hudtype 3, hudtype 5',
    '🫱🏼‍🫲🏿' => 'handhelse: hudtype 3, hudtype 6',
    '🫱🏽‍🫲🏻' => 'handhelse: hudtype 4, hudtype 1–2',
    '🫱🏽‍🫲🏼' => 'handhelse: hudtype 4, hudtype 3',
    '🫱🏽‍🫲🏾' => 'handhelse: hudtype 4, hudtype 5',
    '🫱🏽‍🫲🏿' => 'handhelse: hudtype 4, hudtype 6',
    '🫱🏾‍🫲🏻' => 'handhelse: hudtype 5, hudtype 1–2',
    '🫱🏾‍🫲🏼' => 'handhelse: hudtype 5, hudtype 3',
    '🫱🏾‍🫲🏽' => 'handhelse: hudtype 5, hudtype 4',
    '🫱🏾‍🫲🏿' => 'handhelse: hudtype 5, hudtype 6',
    '🫱🏿‍🫲🏻' => 'handhelse: hudtype 6, hudtype 1–2',
    '🫱🏿‍🫲🏼' => 'handhelse: hudtype 6, hudtype 3',
    '🫱🏿‍🫲🏽' => 'handhelse: hudtype 6, hudtype 4',
    '🫱🏿‍🫲🏾' => 'handhelse: hudtype 6, hudtype 5',
    '🚶‍♀‍➡' => 'kvinneleg fotgjengar: vendt mot høgre',
    '🚶‍♂‍➡' => 'mannleg fotgjengar: vendt mot høgre',
    '🧎‍♀‍➡' => 'kvinne som kneler: vendt mot høgre',
    '🧎‍♂‍➡' => 'mann som kneler: vendt mot høgre',
    '🧑‍🦯‍➡' => 'person med blindestokk: vendt mot høgre',
    '👨‍🦯‍➡' => 'mann med blindestokk: vendt mot høgre',
    '👩‍🦯‍➡' => 'kvinne med blindestokk: vendt mot høgre',
    '🧑‍🦼‍➡' => 'person i motorisert rullestol: vendt mot høgre',
    '👨‍🦼‍➡' => 'mann i motorisert rullestol: vendt mot høgre',
    '👩‍🦼‍➡' => 'kvinne i motorisert rullestol: vendt mot høgre',
    '🧑‍🦽‍➡' => 'person i manuell rullestol: vendt mot høgre',
    '👨‍🦽‍➡' => 'mann i manuell rullestol: vendt mot høgre',
    '👩‍🦽‍➡' => 'kvinne i manuell rullestol: vendt mot høgre',
    '🏃‍♀‍➡' => 'kvineleg løpar: vendt mot høgre',
    '🏃‍♂‍➡' => 'mannleg løpar: vendt mot høgre',
    '👩‍❤‍👨' => 'par med hjarte: kvinne, mann',
    '👨‍❤‍👨' => 'par med hjarte: mann, mann',
    '👩‍❤‍👩' => 'par med hjarte: kvinne, kvinne',
    '👨‍👩‍👦' => 'familie: mann, kvinne, gut',
    '👨‍👨‍👦' => 'familie: mann, mann, gut',
    '👩‍👩‍👦' => 'familie: kvinne, kvinne, gut',
    '👨‍👦‍👦' => 'familie: mann, gut, gut',
    '👨‍👧‍👦' => 'familie: mann, jente, gut',
    '👩‍👦‍👦' => 'familie: kvinne, gut, gut',
    '👩‍👧‍👦' => 'familie: kvinne, jente, gut',
    '🧑‍🤝‍🧑' => 'personar som leiar',
    '🧑‍🧑‍🧒' => 'familie: vaksen, vaksen, barn',
    '🧑‍🧒‍🧒' => 'familie: vaksen, barn, barn',
    '🧑🏻‍🦰' => 'vaksen: hudtype 1–2, raudt hår',
    '🧑🏼‍🦰' => 'vaksen: hudtype 3, raudt hår',
    '🧑🏽‍🦰' => 'vaksen: hudtype 4, raudt hår',
    '🧑🏾‍🦰' => 'vaksen: hudtype 5, raudt hår',
    '🧑🏿‍🦰' => 'vaksen: hudtype 6, raudt hår',
    '🧑🏻‍🦱' => 'vaksen: hudtype 1–2, krusete hår',
    '🧑🏼‍🦱' => 'vaksen: hudtype 3, krusete hår',
    '🧑🏽‍🦱' => 'vaksen: hudtype 4, krusete hår',
    '🧑🏾‍🦱' => 'vaksen: hudtype 5, krusete hår',
    '🧑🏿‍🦱' => 'vaksen: hudtype 6, krusete hår',
    '🧑🏻‍🦳' => 'vaksen: hudtype 1–2, grått hår',
    '🧑🏼‍🦳' => 'vaksen: hudtype 3, grått hår',
    '🧑🏽‍🦳' => 'vaksen: hudtype 4, grått hår',
    '🧑🏾‍🦳' => 'vaksen: hudtype 5, grått hår',
    '🧑🏿‍🦳' => 'vaksen: hudtype 6, grått hår',
    '🧑🏻‍🦲' => 'vaksen: hudtype 1–2, skalla',
    '🧑🏼‍🦲' => 'vaksen: hudtype 3, skalla',
    '🧑🏽‍🦲' => 'vaksen: hudtype 4, skalla',
    '🧑🏾‍🦲' => 'vaksen: hudtype 5, skalla',
    '🧑🏿‍🦲' => 'vaksen: hudtype 6, skalla',
    '🧑🏻‍🩰' => 'ballettdansar: hudtype 1–2',
    '🧑🏼‍🩰' => 'ballettdansar: hudtype 3',
    '🧑🏽‍🩰' => 'ballettdansar: hudtype 4',
    '🧑🏾‍🩰' => 'ballettdansar: hudtype 5',
    '🧑🏿‍🩰' => 'ballettdansar: hudtype 6',
    '👨🏻‍🦰' => 'mann: hudtype 1–2, raudt hår',
    '👨🏼‍🦰' => 'mann: hudtype 3, raudt hår',
    '👨🏽‍🦰' => 'mann: hudtype 4, raudt hår',
    '👨🏾‍🦰' => 'mann: hudtype 5, raudt hår',
    '👨🏿‍🦰' => 'mann: hudtype 6, raudt hår',
    '👨🏻‍🦱' => 'mann: hudtype 1–2, krusete hår',
    '👨🏼‍🦱' => 'mann: hudtype 3, krusete hår',
    '👨🏽‍🦱' => 'mann: hudtype 4, krusete hår',
    '👨🏾‍🦱' => 'mann: hudtype 5, krusete hår',
    '👨🏿‍🦱' => 'mann: hudtype 6, krusete hår',
    '👨🏻‍🦲' => 'mann: hudtype 1–2, skalla',
    '👨🏼‍🦲' => 'mann: hudtype 3, skalla',
    '👨🏽‍🦲' => 'mann: hudtype 4, skalla',
    '👨🏾‍🦲' => 'mann: hudtype 5, skalla',
    '👨🏿‍🦲' => 'mann: hudtype 6, skalla',
    '👩🏻‍🦰' => 'kvinne: hudtype 1–2, raudt hår',
    '👩🏼‍🦰' => 'kvinne: hudtype 3, raudt hår',
    '👩🏽‍🦰' => 'kvinne: hudtype 4, raudt hår',
    '👩🏾‍🦰' => 'kvinne: hudtype 5, raudt hår',
    '👩🏿‍🦰' => 'kvinne: hudtype 6, raudt hår',
    '👩🏻‍🦱' => 'kvinne: hudtype 1–2, krusete hår',
    '👩🏼‍🦱' => 'kvinne: hudtype 3, krusete hår',
    '👩🏽‍🦱' => 'kvinne: hudtype 4, krusete hår',
    '👩🏾‍🦱' => 'kvinne: hudtype 5, krusete hår',
    '👩🏿‍🦱' => 'kvinne: hudtype 6, krusete hår',
    '👩🏻‍🦲' => 'kvinne: hudtype 1–2, skalla',
    '👩🏼‍🦲' => 'kvinne: hudtype 3, skalla',
    '👩🏽‍🦲' => 'kvinne: hudtype 4, skalla',
    '👩🏾‍🦲' => 'kvinne: hudtype 5, skalla',
    '👩🏿‍🦲' => 'kvinne: hudtype 6, skalla',
    '🙍🏻‍♂' => 'mann som rynkar bryna: hudtype 1–2',
    '🙍🏼‍♂' => 'mann som rynkar bryna: hudtype 3',
    '🙍🏽‍♂' => 'mann som rynkar bryna: hudtype 4',
    '🙍🏾‍♂' => 'mann som rynkar bryna: hudtype 5',
    '🙍🏿‍♂' => 'mann som rynkar bryna: hudtype 6',
    '🙍🏻‍♀' => 'kvinne som rynkar bryna: hudtype 1–2',
    '🙍🏼‍♀' => 'kvinne som rynkar bryna: hudtype 3',
    '🙍🏽‍♀' => 'kvinne som rynkar bryna: hudtype 4',
    '🙍🏾‍♀' => 'kvinne som rynkar bryna: hudtype 5',
    '🙍🏿‍♀' => 'kvinne som rynkar bryna: hudtype 6',
    '🙎🏻‍♂' => 'mann som furtar: hudtype 1–2',
    '🙎🏼‍♂' => 'mann som furtar: hudtype 3',
    '🙎🏽‍♂' => 'mann som furtar: hudtype 4',
    '🙎🏾‍♂' => 'mann som furtar: hudtype 5',
    '🙎🏿‍♂' => 'mann som furtar: hudtype 6',
    '🙎🏻‍♀' => 'kvinne som furtar: hudtype 1–2',
    '🙎🏼‍♀' => 'kvinne som furtar: hudtype 3',
    '🙎🏽‍♀' => 'kvinne som furtar: hudtype 4',
    '🙎🏾‍♀' => 'kvinne som furtar: hudtype 5',
    '🙎🏿‍♀' => 'kvinne som furtar: hudtype 6',
    '💁🏻‍♂' => 'hjelpande mann: hudtype 1–2',
    '💁🏼‍♂' => 'hjelpande mann: hudtype 3',
    '💁🏽‍♂' => 'hjelpande mann: hudtype 4',
    '💁🏾‍♂' => 'hjelpande mann: hudtype 5',
    '💁🏿‍♂' => 'hjelpande mann: hudtype 6',
    '💁🏻‍♀' => 'hjelpande kvinne: hudtype 1–2',
    '💁🏼‍♀' => 'hjelpande kvinne: hudtype 3',
    '💁🏽‍♀' => 'hjelpande kvinne: hudtype 4',
    '💁🏾‍♀' => 'hjelpande kvinne: hudtype 5',
    '💁🏿‍♀' => 'hjelpande kvinne: hudtype 6',
    '🙋🏻‍♂' => 'mann som rekker opp handa: hudtype 1–2',
    '🙋🏼‍♂' => 'mann som rekker opp handa: hudtype 3',
    '🙋🏽‍♂' => 'mann som rekker opp handa: hudtype 4',
    '🙋🏾‍♂' => 'mann som rekker opp handa: hudtype 5',
    '🙋🏿‍♂' => 'mann som rekker opp handa: hudtype 6',
    '🙋🏻‍♀' => 'kvinne som rekker opp handa: hudtype 1–2',
    '🙋🏼‍♀' => 'kvinne som rekker opp handa: hudtype 3',
    '🙋🏽‍♀' => 'kvinne som rekker opp handa: hudtype 4',
    '🙋🏾‍♀' => 'kvinne som rekker opp handa: hudtype 5',
    '🙋🏿‍♀' => 'kvinne som rekker opp handa: hudtype 6',
    '🙇🏻‍♂' => 'bukkande mann: hudtype 1–2',
    '🙇🏼‍♂' => 'bukkande mann: hudtype 3',
    '🙇🏽‍♂' => 'bukkande mann: hudtype 4',
    '🙇🏾‍♂' => 'bukkande mann: hudtype 5',
    '🙇🏿‍♂' => 'bukkande mann: hudtype 6',
    '🙇🏻‍♀' => 'bukkande kvinne: hudtype 1–2',
    '🙇🏼‍♀' => 'bukkande kvinne: hudtype 3',
    '🙇🏽‍♀' => 'bukkande kvinne: hudtype 4',
    '🙇🏾‍♀' => 'bukkande kvinne: hudtype 5',
    '🙇🏿‍♀' => 'bukkande kvinne: hudtype 6',
    '🤦🏻‍♂' => 'mann som slår handa mot panna: hudtype 1–2',
    '🤦🏼‍♂' => 'mann som slår handa mot panna: hudtype 3',
    '🤦🏽‍♂' => 'mann som slår handa mot panna: hudtype 4',
    '🤦🏾‍♂' => 'mann som slår handa mot panna: hudtype 5',
    '🤦🏿‍♂' => 'mann som slår handa mot panna: hudtype 6',
    '🤦🏻‍♀' => 'kvinne som slår handa mot panna: hudtype 1–2',
    '🤦🏼‍♀' => 'kvinne som slår handa mot panna: hudtype 3',
    '🤦🏽‍♀' => 'kvinne som slår handa mot panna: hudtype 4',
    '🤦🏾‍♀' => 'kvinne som slår handa mot panna: hudtype 5',
    '🤦🏿‍♀' => 'kvinne som slår handa mot panna: hudtype 6',
    '🤷🏻‍♂' => 'mann som trekkjer på skuldrene: hudtype 1–2',
    '🤷🏼‍♂' => 'mann som trekkjer på skuldrene: hudtype 3',
    '🤷🏽‍♂' => 'mann som trekkjer på skuldrene: hudtype 4',
    '🤷🏾‍♂' => 'mann som trekkjer på skuldrene: hudtype 5',
    '🤷🏿‍♂' => 'mann som trekkjer på skuldrene: hudtype 6',
    '🤷🏻‍♀' => 'kvinne som trekkjer på skuldrene: hudtype 1–2',
    '🤷🏼‍♀' => 'kvinne som trekkjer på skuldrene: hudtype 3',
    '🤷🏽‍♀' => 'kvinne som trekkjer på skuldrene: hudtype 4',
    '🤷🏾‍♀' => 'kvinne som trekkjer på skuldrene: hudtype 5',
    '🤷🏿‍♀' => 'kvinne som trekkjer på skuldrene: hudtype 6',
    '🧑🏻‍⚕' => 'helsearbeidar: hudtype 1–2',
    '🧑🏼‍⚕' => 'helsearbeidar: hudtype 3',
    '🧑🏽‍⚕' => 'helsearbeidar: hudtype 4',
    '🧑🏾‍⚕' => 'helsearbeidar: hudtype 5',
    '🧑🏿‍⚕' => 'helsearbeidar: hudtype 6',
    '👨🏻‍⚕' => 'mannleg helsearbeidar: hudtype 1–2',
    '👨🏼‍⚕' => 'mannleg helsearbeidar: hudtype 3',
    '👨🏽‍⚕' => 'mannleg helsearbeidar: hudtype 4',
    '👨🏾‍⚕' => 'mannleg helsearbeidar: hudtype 5',
    '👨🏿‍⚕' => 'mannleg helsearbeidar: hudtype 6',
    '👩🏻‍⚕' => 'kvinneleg helsearbeidar: hudtype 1–2',
    '👩🏼‍⚕' => 'kvinneleg helsearbeidar: hudtype 3',
    '👩🏽‍⚕' => 'kvinneleg helsearbeidar: hudtype 4',
    '👩🏾‍⚕' => 'kvinneleg helsearbeidar: hudtype 5',
    '👩🏿‍⚕' => 'kvinneleg helsearbeidar: hudtype 6',
    '👨🏻‍🎓' => 'mannleg student: hudtype 1–2',
    '👨🏼‍🎓' => 'mannleg student: hudtype 3',
    '👨🏽‍🎓' => 'mannleg student: hudtype 4',
    '👨🏾‍🎓' => 'mannleg student: hudtype 5',
    '👨🏿‍🎓' => 'mannleg student: hudtype 6',
    '👩🏻‍🎓' => 'kvinneleg student: hudtype 1–2',
    '👩🏼‍🎓' => 'kvinneleg student: hudtype 3',
    '👩🏽‍🎓' => 'kvinneleg student: hudtype 4',
    '👩🏾‍🎓' => 'kvinneleg student: hudtype 5',
    '👩🏿‍🎓' => 'kvinneleg student: hudtype 6',
    '🧑🏻‍🏫' => 'lærar: hudtype 1–2',
    '🧑🏼‍🏫' => 'lærar: hudtype 3',
    '🧑🏽‍🏫' => 'lærar: hudtype 4',
    '🧑🏾‍🏫' => 'lærar: hudtype 5',
    '🧑🏿‍🏫' => 'lærar: hudtype 6',
    '👨🏻‍🏫' => 'mannleg lærar: hudtype 1–2',
    '👨🏼‍🏫' => 'mannleg lærar: hudtype 3',
    '👨🏽‍🏫' => 'mannleg lærar: hudtype 4',
    '👨🏾‍🏫' => 'mannleg lærar: hudtype 5',
    '👨🏿‍🏫' => 'mannleg lærar: hudtype 6',
    '👩🏻‍🏫' => 'kvinneleg lærar: hudtype 1–2',
    '👩🏼‍🏫' => 'kvinneleg lærar: hudtype 3',
    '👩🏽‍🏫' => 'kvinneleg lærar: hudtype 4',
    '👩🏾‍🏫' => 'kvinneleg lærar: hudtype 5',
    '👩🏿‍🏫' => 'kvinneleg lærar: hudtype 6',
    '🧑🏻‍⚖' => 'dommar: hudtype 1–2',
    '🧑🏼‍⚖' => 'dommar: hudtype 3',
    '🧑🏽‍⚖' => 'dommar: hudtype 4',
    '🧑🏾‍⚖' => 'dommar: hudtype 5',
    '🧑🏿‍⚖' => 'dommar: hudtype 6',
    '👨🏻‍⚖' => 'mannleg dommar: hudtype 1–2',
    '👨🏼‍⚖' => 'mannleg dommar: hudtype 3',
    '👨🏽‍⚖' => 'mannleg dommar: hudtype 4',
    '👨🏾‍⚖' => 'mannleg dommar: hudtype 5',
    '👨🏿‍⚖' => 'mannleg dommar: hudtype 6',
    '👩🏻‍⚖' => 'kvinneleg dommar: hudtype 1–2',
    '👩🏼‍⚖' => 'kvinneleg dommar: hudtype 3',
    '👩🏽‍⚖' => 'kvinneleg dommar: hudtype 4',
    '👩🏾‍⚖' => 'kvinneleg dommar: hudtype 5',
    '👩🏿‍⚖' => 'kvinneleg dommar: hudtype 6',
    '🧑🏻‍🌾' => 'gardbrukar: hudtype 1–2',
    '🧑🏼‍🌾' => 'gardbrukar: hudtype 3',
    '🧑🏽‍🌾' => 'gardbrukar: hudtype 4',
    '🧑🏾‍🌾' => 'gardbrukar: hudtype 5',
    '🧑🏿‍🌾' => 'gardbrukar: hudtype 6',
    '👨🏻‍🌾' => 'mannleg gardbrukar: hudtype 1–2',
    '👨🏼‍🌾' => 'mannleg gardbrukar: hudtype 3',
    '👨🏽‍🌾' => 'mannleg gardbrukar: hudtype 4',
    '👨🏾‍🌾' => 'mannleg gardbrukar: hudtype 5',
    '👨🏿‍🌾' => 'mannleg gardbrukar: hudtype 6',
    '👩🏻‍🌾' => 'kvinneleg gardbrukar: hudtype 1–2',
    '👩🏼‍🌾' => 'kvinneleg gardbrukar: hudtype 3',
    '👩🏽‍🌾' => 'kvinneleg gardbrukar: hudtype 4',
    '👩🏾‍🌾' => 'kvinneleg gardbrukar: hudtype 5',
    '👩🏿‍🌾' => 'kvinneleg gardbrukar: hudtype 6',
    '👨🏻‍🍳' => 'mannleg kokk: hudtype 1–2',
    '👨🏼‍🍳' => 'mannleg kokk: hudtype 3',
    '👨🏽‍🍳' => 'mannleg kokk: hudtype 4',
    '👨🏾‍🍳' => 'mannleg kokk: hudtype 5',
    '👨🏿‍🍳' => 'mannleg kokk: hudtype 6',
    '👩🏻‍🍳' => 'kvinneleg kokk: hudtype 1–2',
    '👩🏼‍🍳' => 'kvinneleg kokk: hudtype 3',
    '👩🏽‍🍳' => 'kvinneleg kokk: hudtype 4',
    '👩🏾‍🍳' => 'kvinneleg kokk: hudtype 5',
    '👩🏿‍🍳' => 'kvinneleg kokk: hudtype 6',
    '🧑🏻‍🔧' => 'mekanikar: hudtype 1–2',
    '🧑🏼‍🔧' => 'mekanikar: hudtype 3',
    '🧑🏽‍🔧' => 'mekanikar: hudtype 4',
    '🧑🏾‍🔧' => 'mekanikar: hudtype 5',
    '🧑🏿‍🔧' => 'mekanikar: hudtype 6',
    '👨🏻‍🔧' => 'mannleg mekanikar: hudtype 1–2',
    '👨🏼‍🔧' => 'mannleg mekanikar: hudtype 3',
    '👨🏽‍🔧' => 'mannleg mekanikar: hudtype 4',
    '👨🏾‍🔧' => 'mannleg mekanikar: hudtype 5',
    '👨🏿‍🔧' => 'mannleg mekanikar: hudtype 6',
    '👩🏻‍🔧' => 'kvinneleg mekanikar: hudtype 1–2',
    '👩🏼‍🔧' => 'kvinneleg mekanikar: hudtype 3',
    '👩🏽‍🔧' => 'kvinneleg mekanikar: hudtype 4',
    '👩🏾‍🔧' => 'kvinneleg mekanikar: hudtype 5',
    '👩🏿‍🔧' => 'kvinneleg mekanikar: hudtype 6',
    '🧑🏻‍🏭' => 'industriarbeidar: hudtype 1–2',
    '🧑🏼‍🏭' => 'industriarbeidar: hudtype 3',
    '🧑🏽‍🏭' => 'industriarbeidar: hudtype 4',
    '🧑🏾‍🏭' => 'industriarbeidar: hudtype 5',
    '🧑🏿‍🏭' => 'industriarbeidar: hudtype 6',
    '👨🏻‍🏭' => 'mannleg industriarbeidar: hudtype 1–2',
    '👨🏼‍🏭' => 'mannleg industriarbeidar: hudtype 3',
    '👨🏽‍🏭' => 'mannleg industriarbeidar: hudtype 4',
    '👨🏾‍🏭' => 'mannleg industriarbeidar: hudtype 5',
    '👨🏿‍🏭' => 'mannleg industriarbeidar: hudtype 6',
    '👩🏻‍🏭' => 'kvinneleg industriarbeidar: hudtype 1–2',
    '👩🏼‍🏭' => 'kvinneleg industriarbeidar: hudtype 3',
    '👩🏽‍🏭' => 'kvinneleg industriarbeidar: hudtype 4',
    '👩🏾‍🏭' => 'kvinneleg industriarbeidar: hudtype 5',
    '👩🏿‍🏭' => 'kvinneleg industriarbeidar: hudtype 6',
    '🧑🏻‍💼' => 'kontorarbeidar: hudtype 1–2',
    '🧑🏼‍💼' => 'kontorarbeidar: hudtype 3',
    '🧑🏽‍💼' => 'kontorarbeidar: hudtype 4',
    '🧑🏾‍💼' => 'kontorarbeidar: hudtype 5',
    '🧑🏿‍💼' => 'kontorarbeidar: hudtype 6',
    '👨🏻‍💼' => 'mannleg kontorarbeidar: hudtype 1–2',
    '👨🏼‍💼' => 'mannleg kontorarbeidar: hudtype 3',
    '👨🏽‍💼' => 'mannleg kontorarbeidar: hudtype 4',
    '👨🏾‍💼' => 'mannleg kontorarbeidar: hudtype 5',
    '👨🏿‍💼' => 'mannleg kontorarbeidar: hudtype 6',
    '👩🏻‍💼' => 'kvinneleg kontorarbeidar: hudtype 1–2',
    '👩🏼‍💼' => 'kvinneleg kontorarbeidar: hudtype 3',
    '👩🏽‍💼' => 'kvinneleg kontorarbeidar: hudtype 4',
    '👩🏾‍💼' => 'kvinneleg kontorarbeidar: hudtype 5',
    '👩🏿‍💼' => 'kvinneleg kontorarbeidar: hudtype 6',
    '🧑🏻‍🔬' => 'forskar: hudtype 1–2',
    '🧑🏼‍🔬' => 'forskar: hudtype 3',
    '🧑🏽‍🔬' => 'forskar: hudtype 4',
    '🧑🏾‍🔬' => 'forskar: hudtype 5',
    '🧑🏿‍🔬' => 'forskar: hudtype 6',
    '👨🏻‍🔬' => 'mannleg forskar: hudtype 1–2',
    '👨🏼‍🔬' => 'mannleg forskar: hudtype 3',
    '👨🏽‍🔬' => 'mannleg forskar: hudtype 4',
    '👨🏾‍🔬' => 'mannleg forskar: hudtype 5',
    '👨🏿‍🔬' => 'mannleg forskar: hudtype 6',
    '👩🏻‍🔬' => 'kvinneleg forskar: hudtype 1–2',
    '👩🏼‍🔬' => 'kvinneleg forskar: hudtype 3',
    '👩🏽‍🔬' => 'kvinneleg forskar: hudtype 4',
    '👩🏾‍🔬' => 'kvinneleg forskar: hudtype 5',
    '👩🏿‍🔬' => 'kvinneleg forskar: hudtype 6',
    '👨🏻‍💻' => 'mannleg IT-ekspert: hudtype 1–2',
    '👨🏼‍💻' => 'mannleg IT-ekspert: hudtype 3',
    '👨🏽‍💻' => 'mannleg IT-ekspert: hudtype 4',
    '👨🏾‍💻' => 'mannleg IT-ekspert: hudtype 5',
    '👨🏿‍💻' => 'mannleg IT-ekspert: hudtype 6',
    '👩🏻‍💻' => 'kvinneleg IT-ekspert: hudtype 1–2',
    '👩🏼‍💻' => 'kvinneleg IT-ekspert: hudtype 3',
    '👩🏽‍💻' => 'kvinneleg IT-ekspert: hudtype 4',
    '👩🏾‍💻' => 'kvinneleg IT-ekspert: hudtype 5',
    '👩🏿‍💻' => 'kvinneleg IT-ekspert: hudtype 6',
    '👨🏻‍🎤' => 'mannleg artist: hudtype 1–2',
    '👨🏼‍🎤' => 'mannleg artist: hudtype 3',
    '👨🏽‍🎤' => 'mannleg artist: hudtype 4',
    '👨🏾‍🎤' => 'mannleg artist: hudtype 5',
    '👨🏿‍🎤' => 'mannleg artist: hudtype 6',
    '👩🏻‍🎤' => 'kvinneleg artist: hudtype 1–2',
    '👩🏼‍🎤' => 'kvinneleg artist: hudtype 3',
    '👩🏽‍🎤' => 'kvinneleg artist: hudtype 4',
    '👩🏾‍🎤' => 'kvinneleg artist: hudtype 5',
    '👩🏿‍🎤' => 'kvinneleg artist: hudtype 6',
    '🧑🏻‍🎨' => 'kunstnar: hudtype 1–2',
    '🧑🏼‍🎨' => 'kunstnar: hudtype 3',
    '🧑🏽‍🎨' => 'kunstnar: hudtype 4',
    '🧑🏾‍🎨' => 'kunstnar: hudtype 5',
    '🧑🏿‍🎨' => 'kunstnar: hudtype 6',
    '👨🏻‍🎨' => 'mannleg kunstnar: hudtype 1–2',
    '👨🏼‍🎨' => 'mannleg kunstnar: hudtype 3',
    '👨🏽‍🎨' => 'mannleg kunstnar: hudtype 4',
    '👨🏾‍🎨' => 'mannleg kunstnar: hudtype 5',
    '👨🏿‍🎨' => 'mannleg kunstnar: hudtype 6',
    '👩🏻‍🎨' => 'kvinneleg kunstnar: hudtype 1–2',
    '👩🏼‍🎨' => 'kvinneleg kunstnar: hudtype 3',
    '👩🏽‍🎨' => 'kvinneleg kunstnar: hudtype 4',
    '👩🏾‍🎨' => 'kvinneleg kunstnar: hudtype 5',
    '👩🏿‍🎨' => 'kvinneleg kunstnar: hudtype 6',
    '👨🏻‍✈' => 'mannleg pilot: hudtype 1–2',
    '👨🏼‍✈' => 'mannleg pilot: hudtype 3',
    '👨🏽‍✈' => 'mannleg pilot: hudtype 4',
    '👨🏾‍✈' => 'mannleg pilot: hudtype 5',
    '👨🏿‍✈' => 'mannleg pilot: hudtype 6',
    '👩🏻‍✈' => 'kvinneleg pilot: hudtype 1–2',
    '👩🏼‍✈' => 'kvinneleg pilot: hudtype 3',
    '👩🏽‍✈' => 'kvinneleg pilot: hudtype 4',
    '👩🏾‍✈' => 'kvinneleg pilot: hudtype 5',
    '👩🏿‍✈' => 'kvinneleg pilot: hudtype 6',
    '👨🏻‍🚀' => 'mannleg astronaut: hudtype 1–2',
    '👨🏼‍🚀' => 'mannleg astronaut: hudtype 3',
    '👨🏽‍🚀' => 'mannleg astronaut: hudtype 4',
    '👨🏾‍🚀' => 'mannleg astronaut: hudtype 5',
    '👨🏿‍🚀' => 'mannleg astronaut: hudtype 6',
    '👩🏻‍🚀' => 'kvinneleg astronaut: hudtype 1–2',
    '👩🏼‍🚀' => 'kvinneleg astronaut: hudtype 3',
    '👩🏽‍🚀' => 'kvinneleg astronaut: hudtype 4',
    '👩🏾‍🚀' => 'kvinneleg astronaut: hudtype 5',
    '👩🏿‍🚀' => 'kvinneleg astronaut: hudtype 6',
    '👨🏻‍🚒' => 'mannleg brannkonstabel: hudtype 1–2',
    '👨🏼‍🚒' => 'mannleg brannkonstabel: hudtype 3',
    '👨🏽‍🚒' => 'mannleg brannkonstabel: hudtype 4',
    '👨🏾‍🚒' => 'mannleg brannkonstabel: hudtype 5',
    '👨🏿‍🚒' => 'mannleg brannkonstabel: hudtype 6',
    '👩🏻‍🚒' => 'kvinneleg brannkonstabel: hudtype 1–2',
    '👩🏼‍🚒' => 'kvinneleg brannkonstabel: hudtype 3',
    '👩🏽‍🚒' => 'kvinneleg brannkonstabel: hudtype 4',
    '👩🏾‍🚒' => 'kvinneleg brannkonstabel: hudtype 5',
    '👩🏿‍🚒' => 'kvinneleg brannkonstabel: hudtype 6',
    '👮🏻‍♂' => 'mannleg politibetjent: hudtype 1–2',
    '👮🏼‍♂' => 'mannleg politibetjent: hudtype 3',
    '👮🏽‍♂' => 'mannleg politibetjent: hudtype 4',
    '👮🏾‍♂' => 'mannleg politibetjent: hudtype 5',
    '👮🏿‍♂' => 'mannleg politibetjent: hudtype 6',
    '👮🏻‍♀' => 'kvinneleg politibetjent: hudtype 1–2',
    '👮🏼‍♀' => 'kvinneleg politibetjent: hudtype 3',
    '👮🏽‍♀' => 'kvinneleg politibetjent: hudtype 4',
    '👮🏾‍♀' => 'kvinneleg politibetjent: hudtype 5',
    '👮🏿‍♀' => 'kvinneleg politibetjent: hudtype 6',
    '🕵🏻‍♂' => 'mannleg detektiv: hudtype 1–2',
    '🕵🏼‍♂' => 'mannleg detektiv: hudtype 3',
    '🕵🏽‍♂' => 'mannleg detektiv: hudtype 4',
    '🕵🏾‍♂' => 'mannleg detektiv: hudtype 5',
    '🕵🏿‍♂' => 'mannleg detektiv: hudtype 6',
    '🕵🏻‍♀' => 'kvinneleg detektiv: hudtype 1–2',
    '🕵🏼‍♀' => 'kvinneleg detektiv: hudtype 3',
    '🕵🏽‍♀' => 'kvinneleg detektiv: hudtype 4',
    '🕵🏾‍♀' => 'kvinneleg detektiv: hudtype 5',
    '🕵🏿‍♀' => 'kvinneleg detektiv: hudtype 6',
    '💂🏻‍♂' => 'mannleg gardist: hudtype 1–2',
    '💂🏼‍♂' => 'mannleg gardist: hudtype 3',
    '💂🏽‍♂' => 'mannleg gardist: hudtype 4',
    '💂🏾‍♂' => 'mannleg gardist: hudtype 5',
    '💂🏿‍♂' => 'mannleg gardist: hudtype 6',
    '💂🏻‍♀' => 'kvinneleg gardist: hudtype 1–2',
    '💂🏼‍♀' => 'kvinneleg gardist: hudtype 3',
    '💂🏽‍♀' => 'kvinneleg gardist: hudtype 4',
    '💂🏾‍♀' => 'kvinneleg gardist: hudtype 5',
    '💂🏿‍♀' => 'kvinneleg gardist: hudtype 6',
    '👷🏻‍♂' => 'mannleg anleggsarbeidar: hudtype 1–2',
    '👷🏼‍♂' => 'mannleg anleggsarbeidar: hudtype 3',
    '👷🏽‍♂' => 'mannleg anleggsarbeidar: hudtype 4',
    '👷🏾‍♂' => 'mannleg anleggsarbeidar: hudtype 5',
    '👷🏿‍♂' => 'mannleg anleggsarbeidar: hudtype 6',
    '👷🏻‍♀' => 'kvinneleg anleggsarbeidar: hudtype 1–2',
    '👷🏼‍♀' => 'kvinneleg anleggsarbeidar: hudtype 3',
    '👷🏽‍♀' => 'kvinneleg anleggsarbeidar: hudtype 4',
    '👷🏾‍♀' => 'kvinneleg anleggsarbeidar: hudtype 5',
    '👷🏿‍♀' => 'kvinneleg anleggsarbeidar: hudtype 6',
    '👩🏻‍🍼' => 'kvinne som matar baby: hudtype 1–2',
    '👩🏼‍🍼' => 'kvinne som matar baby: hudtype 3',
    '👩🏽‍🍼' => 'kvinne som matar baby: hudtype 4',
    '👩🏾‍🍼' => 'kvinne som matar baby: hudtype 5',
    '👩🏿‍🍼' => 'kvinne som matar baby: hudtype 6',
    '👨🏻‍🍼' => 'mann som matar baby: hudtype 1–2',
    '👨🏼‍🍼' => 'mann som matar baby: hudtype 3',
    '👨🏽‍🍼' => 'mann som matar baby: hudtype 4',
    '👨🏾‍🍼' => 'mann som matar baby: hudtype 5',
    '👨🏿‍🍼' => 'mann som matar baby: hudtype 6',
    '🧑🏻‍🍼' => 'person som matar baby: hudtype 1–2',
    '🧑🏼‍🍼' => 'person som matar baby: hudtype 3',
    '🧑🏽‍🍼' => 'person som matar baby: hudtype 4',
    '🧑🏾‍🍼' => 'person som matar baby: hudtype 5',
    '🧑🏿‍🍼' => 'person som matar baby: hudtype 6',
    '🦸🏻‍♂' => 'mannleg superhelt: hudtype 1–2',
    '🦸🏼‍♂' => 'mannleg superhelt: hudtype 3',
    '🦸🏽‍♂' => 'mannleg superhelt: hudtype 4',
    '🦸🏾‍♂' => 'mannleg superhelt: hudtype 5',
    '🦸🏿‍♂' => 'mannleg superhelt: hudtype 6',
    '🦸🏻‍♀' => 'kvinneleg superhelt: hudtype 1–2',
    '🦸🏼‍♀' => 'kvinneleg superhelt: hudtype 3',
    '🦸🏽‍♀' => 'kvinneleg superhelt: hudtype 4',
    '🦸🏾‍♀' => 'kvinneleg superhelt: hudtype 5',
    '🦸🏿‍♀' => 'kvinneleg superhelt: hudtype 6',
    '🦹🏻‍♂' => 'mannleg superskurk: hudtype 1–2',
    '🦹🏼‍♂' => 'mannleg superskurk: hudtype 3',
    '🦹🏽‍♂' => 'mannleg superskurk: hudtype 4',
    '🦹🏾‍♂' => 'mannleg superskurk: hudtype 5',
    '🦹🏿‍♂' => 'mannleg superskurk: hudtype 6',
    '🦹🏻‍♀' => 'kvinneleg superskurk: hudtype 1–2',
    '🦹🏼‍♀' => 'kvinneleg superskurk: hudtype 3',
    '🦹🏽‍♀' => 'kvinneleg superskurk: hudtype 4',
    '🦹🏾‍♀' => 'kvinneleg superskurk: hudtype 5',
    '🦹🏿‍♀' => 'kvinneleg superskurk: hudtype 6',
    '🧚🏻‍♂' => 'mannleg fe: hudtype 1–2',
    '🧚🏼‍♂' => 'mannleg fe: hudtype 3',
    '🧚🏽‍♂' => 'mannleg fe: hudtype 4',
    '🧚🏾‍♂' => 'mannleg fe: hudtype 5',
    '🧚🏿‍♂' => 'mannleg fe: hudtype 6',
    '🧚🏻‍♀' => 'kvinneleg fe: hudtype 1–2',
    '🧚🏼‍♀' => 'kvinneleg fe: hudtype 3',
    '🧚🏽‍♀' => 'kvinneleg fe: hudtype 4',
    '🧚🏾‍♀' => 'kvinneleg fe: hudtype 5',
    '🧚🏿‍♀' => 'kvinneleg fe: hudtype 6',
    '🧛🏻‍♂' => 'mannleg vampyr: hudtype 1–2',
    '🧛🏼‍♂' => 'mannleg vampyr: hudtype 3',
    '🧛🏽‍♂' => 'mannleg vampyr: hudtype 4',
    '🧛🏾‍♂' => 'mannleg vampyr: hudtype 5',
    '🧛🏿‍♂' => 'mannleg vampyr: hudtype 6',
    '🧛🏻‍♀' => 'kvinneleg vampyr: hudtype 1–2',
    '🧛🏼‍♀' => 'kvinneleg vampyr: hudtype 3',
    '🧛🏽‍♀' => 'kvinneleg vampyr: hudtype 4',
    '🧛🏾‍♀' => 'kvinneleg vampyr: hudtype 5',
    '🧛🏿‍♀' => 'kvinneleg vampyr: hudtype 6',
    '🧝🏻‍♂' => 'mannleg alv: hudtype 1–2',
    '🧝🏼‍♂' => 'mannleg alv: hudtype 3',
    '🧝🏽‍♂' => 'mannleg alv: hudtype 4',
    '🧝🏾‍♂' => 'mannleg alv: hudtype 5',
    '🧝🏿‍♂' => 'mannleg alv: hudtype 6',
    '🧝🏻‍♀' => 'kvinneleg alv: hudtype 1–2',
    '🧝🏼‍♀' => 'kvinneleg alv: hudtype 3',
    '🧝🏽‍♀' => 'kvinneleg alv: hudtype 4',
    '🧝🏾‍♀' => 'kvinneleg alv: hudtype 5',
    '🧝🏿‍♀' => 'kvinneleg alv: hudtype 6',
    '💆🏻‍♂' => 'mann som får andletsmassasje: hudtype 1–2',
    '💆🏼‍♂' => 'mann som får andletsmassasje: hudtype 3',
    '💆🏽‍♂' => 'mann som får andletsmassasje: hudtype 4',
    '💆🏾‍♂' => 'mann som får andletsmassasje: hudtype 5',
    '💆🏿‍♂' => 'mann som får andletsmassasje: hudtype 6',
    '💆🏻‍♀' => 'kvinne som får andletsmassasje: hudtype 1–2',
    '💆🏼‍♀' => 'kvinne som får andletsmassasje: hudtype 3',
    '💆🏽‍♀' => 'kvinne som får andletsmassasje: hudtype 4',
    '💆🏾‍♀' => 'kvinne som får andletsmassasje: hudtype 5',
    '💆🏿‍♀' => 'kvinne som får andletsmassasje: hudtype 6',
    '🚶🏻‍♂' => 'mannleg fotgjengar: hudtype 1–2',
    '🚶🏼‍♂' => 'mannleg fotgjengar: hudtype 3',
    '🚶🏽‍♂' => 'mannleg fotgjengar: hudtype 4',
    '🚶🏾‍♂' => 'mannleg fotgjengar: hudtype 5',
    '🚶🏿‍♂' => 'mannleg fotgjengar: hudtype 6',
    '🚶🏻‍♀' => 'kvinneleg fotgjengar: hudtype 1–2',
    '🚶🏼‍♀' => 'kvinneleg fotgjengar: hudtype 3',
    '🚶🏽‍♀' => 'kvinneleg fotgjengar: hudtype 4',
    '🚶🏾‍♀' => 'kvinneleg fotgjengar: hudtype 5',
    '🚶🏿‍♀' => 'kvinneleg fotgjengar: hudtype 6',
    '🚶🏻‍➡' => 'fotgjengar: hudtype 1–2, vendt mot høgre',
    '🚶🏼‍➡' => 'fotgjengar: hudtype 3, vendt mot høgre',
    '🚶🏽‍➡' => 'fotgjengar: hudtype 4, vendt mot høgre',
    '🚶🏾‍➡' => 'fotgjengar: hudtype 5, vendt mot høgre',
    '🚶🏿‍➡' => 'fotgjengar: hudtype 6, vendt mot høgre',
    '🧎🏻‍➡' => 'person som kneler: hudtype 1–2, vendt mot høgre',
    '🧎🏼‍➡' => 'person som kneler: hudtype 3, vendt mot høgre',
    '🧎🏽‍➡' => 'person som kneler: hudtype 4, vendt mot høgre',
    '🧎🏾‍➡' => 'person som kneler: hudtype 5, vendt mot høgre',
    '🧎🏿‍➡' => 'person som kneler: hudtype 6, vendt mot høgre',
    '🏃🏻‍♂' => 'mannleg løpar: hudtype 1–2',
    '🏃🏼‍♂' => 'mannleg løpar: hudtype 3',
    '🏃🏽‍♂' => 'mannleg løpar: hudtype 4',
    '🏃🏾‍♂' => 'mannleg løpar: hudtype 5',
    '🏃🏿‍♂' => 'mannleg løpar: hudtype 6',
    '🏃🏻‍♀' => 'kvineleg løpar: hudtype 1–2',
    '🏃🏼‍♀' => 'kvineleg løpar: hudtype 3',
    '🏃🏽‍♀' => 'kvineleg løpar: hudtype 4',
    '🏃🏾‍♀' => 'kvineleg løpar: hudtype 5',
    '🏃🏿‍♀' => 'kvineleg løpar: hudtype 6',
    '🏃🏻‍➡' => 'løpar: hudtype 1–2, vendt mot høgre',
    '🏃🏼‍➡' => 'løpar: hudtype 3, vendt mot høgre',
    '🏃🏽‍➡' => 'løpar: hudtype 4, vendt mot høgre',
    '🏃🏾‍➡' => 'løpar: hudtype 5, vendt mot høgre',
    '🏃🏿‍➡' => 'løpar: hudtype 6, vendt mot høgre',
    '👯🏻‍♀' => 'kvinner med kaninøyre: hudtype 1–2',
    '👯🏼‍♀' => 'kvinner med kaninøyre: hudtype 3',
    '👯🏽‍♀' => 'kvinner med kaninøyre: hudtype 4',
    '👯🏾‍♀' => 'kvinner med kaninøyre: hudtype 5',
    '👯🏿‍♀' => 'kvinner med kaninøyre: hudtype 6',
    '👯🏻‍♂' => 'menn med kaninøyre: hudtype 1–2',
    '👯🏼‍♂' => 'menn med kaninøyre: hudtype 3',
    '👯🏽‍♂' => 'menn med kaninøyre: hudtype 4',
    '👯🏾‍♂' => 'menn med kaninøyre: hudtype 5',
    '👯🏿‍♂' => 'menn med kaninøyre: hudtype 6',
    '🧖🏻‍♂' => 'mann i badstove: hudtype 1–2',
    '🧖🏼‍♂' => 'mann i badstove: hudtype 3',
    '🧖🏽‍♂' => 'mann i badstove: hudtype 4',
    '🧖🏾‍♂' => 'mann i badstove: hudtype 5',
    '🧖🏿‍♂' => 'mann i badstove: hudtype 6',
    '🧖🏻‍♀' => 'kvinne i badstove: hudtype 1–2',
    '🧖🏼‍♀' => 'kvinne i badstove: hudtype 3',
    '🧖🏽‍♀' => 'kvinne i badstove: hudtype 4',
    '🧖🏾‍♀' => 'kvinne i badstove: hudtype 5',
    '🧖🏿‍♀' => 'kvinne i badstove: hudtype 6',
    '🧗🏻‍♂' => 'mannleg klatrar: hudtype 1–2',
    '🧗🏼‍♂' => 'mannleg klatrar: hudtype 3',
    '🧗🏽‍♂' => 'mannleg klatrar: hudtype 4',
    '🧗🏾‍♂' => 'mannleg klatrar: hudtype 5',
    '🧗🏿‍♂' => 'mannleg klatrar: hudtype 6',
    '🧗🏻‍♀' => 'kvinneleg klatrar: hudtype 1–2',
    '🧗🏼‍♀' => 'kvinneleg klatrar: hudtype 3',
    '🧗🏽‍♀' => 'kvinneleg klatrar: hudtype 4',
    '🧗🏾‍♀' => 'kvinneleg klatrar: hudtype 5',
    '🧗🏿‍♀' => 'kvinneleg klatrar: hudtype 6',
    '🏌🏻‍♂' => 'mannleg golfspelar: hudtype 1–2',
    '🏌🏼‍♂' => 'mannleg golfspelar: hudtype 3',
    '🏌🏽‍♂' => 'mannleg golfspelar: hudtype 4',
    '🏌🏾‍♂' => 'mannleg golfspelar: hudtype 5',
    '🏌🏿‍♂' => 'mannleg golfspelar: hudtype 6',
    '🏌🏻‍♀' => 'kvinneleg golfspelar: hudtype 1–2',
    '🏌🏼‍♀' => 'kvinneleg golfspelar: hudtype 3',
    '🏌🏽‍♀' => 'kvinneleg golfspelar: hudtype 4',
    '🏌🏾‍♀' => 'kvinneleg golfspelar: hudtype 5',
    '🏌🏿‍♀' => 'kvinneleg golfspelar: hudtype 6',
    '🏄🏻‍♂' => 'mannleg surfar: hudtype 1–2',
    '🏄🏼‍♂' => 'mannleg surfar: hudtype 3',
    '🏄🏽‍♂' => 'mannleg surfar: hudtype 4',
    '🏄🏾‍♂' => 'mannleg surfar: hudtype 5',
    '🏄🏿‍♂' => 'mannleg surfar: hudtype 6',
    '🏄🏻‍♀' => 'kvinneleg surfar: hudtype 1–2',
    '🏄🏼‍♀' => 'kvinneleg surfar: hudtype 3',
    '🏄🏽‍♀' => 'kvinneleg surfar: hudtype 4',
    '🏄🏾‍♀' => 'kvinneleg surfar: hudtype 5',
    '🏄🏿‍♀' => 'kvinneleg surfar: hudtype 6',
    '🏊🏻‍♂' => 'mannleg symjar: hudtype 1–2',
    '🏊🏼‍♂' => 'mannleg symjar: hudtype 3',
    '🏊🏽‍♂' => 'mannleg symjar: hudtype 4',
    '🏊🏾‍♂' => 'mannleg symjar: hudtype 5',
    '🏊🏿‍♂' => 'mannleg symjar: hudtype 6',
    '🏊🏻‍♀' => 'kvinneleg symjar: hudtype 1–2',
    '🏊🏼‍♀' => 'kvinneleg symjar: hudtype 3',
    '🏊🏽‍♀' => 'kvinneleg symjar: hudtype 4',
    '🏊🏾‍♀' => 'kvinneleg symjar: hudtype 5',
    '🏊🏿‍♀' => 'kvinneleg symjar: hudtype 6',
    '🏋🏻‍♂' => 'mannleg vektløftar: hudtype 1–2',
    '🏋🏼‍♂' => 'mannleg vektløftar: hudtype 3',
    '🏋🏽‍♂' => 'mannleg vektløftar: hudtype 4',
    '🏋🏾‍♂' => 'mannleg vektløftar: hudtype 5',
    '🏋🏿‍♂' => 'mannleg vektløftar: hudtype 6',
    '🏋🏻‍♀' => 'kvinneleg vektløftar: hudtype 1–2',
    '🏋🏼‍♀' => 'kvinneleg vektløftar: hudtype 3',
    '🏋🏽‍♀' => 'kvinneleg vektløftar: hudtype 4',
    '🏋🏾‍♀' => 'kvinneleg vektløftar: hudtype 5',
    '🏋🏿‍♀' => 'kvinneleg vektløftar: hudtype 6',
    '🚴🏻‍♂' => 'mannleg syklist: hudtype 1–2',
    '🚴🏼‍♂' => 'mannleg syklist: hudtype 3',
    '🚴🏽‍♂' => 'mannleg syklist: hudtype 4',
    '🚴🏾‍♂' => 'mannleg syklist: hudtype 5',
    '🚴🏿‍♂' => 'mannleg syklist: hudtype 6',
    '🚴🏻‍♀' => 'kvinneleg syklist: hudtype 1–2',
    '🚴🏼‍♀' => 'kvinneleg syklist: hudtype 3',
    '🚴🏽‍♀' => 'kvinneleg syklist: hudtype 4',
    '🚴🏾‍♀' => 'kvinneleg syklist: hudtype 5',
    '🚴🏿‍♀' => 'kvinneleg syklist: hudtype 6',
    '🤼🏻‍♀' => 'kvinnelege brytarar: hudtype 1–2',
    '🤼🏼‍♀' => 'kvinnelege brytarar: hudtype 3',
    '🤼🏽‍♀' => 'kvinnelege brytarar: hudtype 4',
    '🤼🏾‍♀' => 'kvinnelege brytarar: hudtype 5',
    '🤼🏿‍♀' => 'kvinnelege brytarar: hudtype 6',
    '🤼🏻‍♂' => 'mannlege brytarar: hudtype 1–2',
    '🤼🏼‍♂' => 'mannlege brytarar: hudtype 3',
    '🤼🏽‍♂' => 'mannlege brytarar: hudtype 4',
    '🤼🏾‍♂' => 'mannlege brytarar: hudtype 5',
    '🤼🏿‍♂' => 'mannlege brytarar: hudtype 6',
    '🤽🏻‍♂' => 'mannleg vasspolospelar: hudtype 1–2',
    '🤽🏼‍♂' => 'mannleg vasspolospelar: hudtype 3',
    '🤽🏽‍♂' => 'mannleg vasspolospelar: hudtype 4',
    '🤽🏾‍♂' => 'mannleg vasspolospelar: hudtype 5',
    '🤽🏿‍♂' => 'mannleg vasspolospelar: hudtype 6',
    '🤽🏻‍♀' => 'kvinneleg vasspolospelar: hudtype 1–2',
    '🤽🏼‍♀' => 'kvinneleg vasspolospelar: hudtype 3',
    '🤽🏽‍♀' => 'kvinneleg vasspolospelar: hudtype 4',
    '🤽🏾‍♀' => 'kvinneleg vasspolospelar: hudtype 5',
    '🤽🏿‍♀' => 'kvinneleg vasspolospelar: hudtype 6',
    '🤾🏻‍♂' => 'mannleg handballspelar: hudtype 1–2',
    '🤾🏼‍♂' => 'mannleg handballspelar: hudtype 3',
    '🤾🏽‍♂' => 'mannleg handballspelar: hudtype 4',
    '🤾🏾‍♂' => 'mannleg handballspelar: hudtype 5',
    '🤾🏿‍♂' => 'mannleg handballspelar: hudtype 6',
    '🤾🏻‍♀' => 'kvinneleg handballspelar: hudtype 1–2',
    '🤾🏼‍♀' => 'kvinneleg handballspelar: hudtype 3',
    '🤾🏽‍♀' => 'kvinneleg handballspelar: hudtype 4',
    '🤾🏾‍♀' => 'kvinneleg handballspelar: hudtype 5',
    '🤾🏿‍♀' => 'kvinneleg handballspelar: hudtype 6',
    '🤹🏻‍♂' => 'mannleg sjonglør: hudtype 1–2',
    '🤹🏼‍♂' => 'mannleg sjonglør: hudtype 3',
    '🤹🏽‍♂' => 'mannleg sjonglør: hudtype 4',
    '🤹🏾‍♂' => 'mannleg sjonglør: hudtype 5',
    '🤹🏿‍♂' => 'mannleg sjonglør: hudtype 6',
    '🤹🏻‍♀' => 'kvinneleg sjonglør: hudtype 1–2',
    '🤹🏼‍♀' => 'kvinneleg sjonglør: hudtype 3',
    '🤹🏽‍♀' => 'kvinneleg sjonglør: hudtype 4',
    '🤹🏾‍♀' => 'kvinneleg sjonglør: hudtype 5',
    '🤹🏿‍♀' => 'kvinneleg sjonglør: hudtype 6',
    '🧑‍🦰' => 'vaksen: raudt hår',
    '🧑‍🦱' => 'vaksen: krusete hår',
    '🧑‍🦳' => 'vaksen: grått hår',
    '🧑‍🦲' => 'vaksen: skalla',
    '👨‍🦰' => 'mann: raudt hår',
    '👨‍🦱' => 'mann: krusete hår',
    '👨‍🦲' => 'mann: skalla',
    '👩‍🦰' => 'kvinne: raudt hår',
    '👩‍🦱' => 'kvinne: krusete hår',
    '👩‍🦲' => 'kvinne: skalla',
    '🚶‍➡' => 'fotgjengar: vendt mot høgre',
    '🧎‍➡' => 'person som kneler: vendt mot høgre',
    '🏃‍➡' => 'løpar: vendt mot høgre',
    '👨‍👦' => 'familie: mann, gut',
    '👩‍👦' => 'familie: kvinne, gut',
    '😮‍💨' => 'pustar ut',
    '🙂‍↕' => 'nikkande hovud',
    '😵‍💫' => 'fjes med spiralauge',
    '❤‍🔥' => 'hjarte i brann',
    '❤‍🩹' => 'lindra hjarte',
    '👁‍🗨' => 'auge i snakkeboble',
    '🙍‍♂' => 'mann som rynkar bryna',
    '🙍‍♀' => 'kvinne som rynkar bryna',
    '🙎‍♂' => 'mann som furtar',
    '🙎‍♀' => 'kvinne som furtar',
    '💁‍♂' => 'hjelpande mann',
    '💁‍♀' => 'hjelpande kvinne',
    '🙋‍♂' => 'mann som rekker opp handa',
    '🙋‍♀' => 'kvinne som rekker opp handa',
    '🙇‍♂' => 'bukkande mann',
    '🙇‍♀' => 'bukkande kvinne',
    '🤦‍♂' => 'mann som slår handa mot panna',
    '🤦‍♀' => 'kvinne som slår handa mot panna',
    '🤷‍♂' => 'mann som trekkjer på skuldrene',
    '🤷‍♀' => 'kvinne som trekkjer på skuldrene',
    '🧑‍⚕' => 'helsearbeidar',
    '👨‍⚕' => 'mannleg helsearbeidar',
    '👩‍⚕' => 'kvinneleg helsearbeidar',
    '👨‍🎓' => 'mannleg student',
    '👩‍🎓' => 'kvinneleg student',
    '🧑‍🏫' => 'lærar',
    '👨‍🏫' => 'mannleg lærar',
    '👩‍🏫' => 'kvinneleg lærar',
    '🧑‍⚖' => 'dommar',
    '👨‍⚖' => 'mannleg dommar',
    '👩‍⚖' => 'kvinneleg dommar',
    '🧑‍🌾' => 'gardbrukar',
    '👨‍🌾' => 'mannleg gardbrukar',
    '👩‍🌾' => 'kvinneleg gardbrukar',
    '👨‍🍳' => 'mannleg kokk',
    '👩‍🍳' => 'kvinneleg kokk',
    '🧑‍🔧' => 'mekanikar',
    '👨‍🔧' => 'mannleg mekanikar',
    '👩‍🔧' => 'kvinneleg mekanikar',
    '🧑‍🏭' => 'industriarbeidar',
    '👨‍🏭' => 'mannleg industriarbeidar',
    '👩‍🏭' => 'kvinneleg industriarbeidar',
    '🧑‍💼' => 'kontorarbeidar',
    '👨‍💼' => 'mannleg kontorarbeidar',
    '👩‍💼' => 'kvinneleg kontorarbeidar',
    '🧑‍🔬' => 'forskar',
    '👨‍🔬' => 'mannleg forskar',
    '👩‍🔬' => 'kvinneleg forskar',
    '👨‍💻' => 'mannleg IT-ekspert',
    '👩‍💻' => 'kvinneleg IT-ekspert',
    '👨‍🎤' => 'mannleg artist',
    '👩‍🎤' => 'kvinneleg artist',
    '🧑‍🎨' => 'kunstnar',
    '👨‍🎨' => 'mannleg kunstnar',
    '👩‍🎨' => 'kvinneleg kunstnar',
    '👨‍✈' => 'mannleg pilot',
    '👩‍✈' => 'kvinneleg pilot',
    '👨‍🚀' => 'mannleg astronaut',
    '👩‍🚀' => 'kvinneleg astronaut',
    '👨‍🚒' => 'mannleg brannkonstabel',
    '👩‍🚒' => 'kvinneleg brannkonstabel',
    '👮‍♂' => 'mannleg politibetjent',
    '👮‍♀' => 'kvinneleg politibetjent',
    '🕵‍♂' => 'mannleg detektiv',
    '🕵‍♀' => 'kvinneleg detektiv',
    '💂‍♂' => 'mannleg gardist',
    '💂‍♀' => 'kvinneleg gardist',
    '👷‍♂' => 'mannleg anleggsarbeidar',
    '👷‍♀' => 'kvinneleg anleggsarbeidar',
    '👩‍🍼' => 'kvinne som matar baby',
    '👨‍🍼' => 'mann som matar baby',
    '🧑‍🍼' => 'person som matar baby',
    '🦸‍♂' => 'mannleg superhelt',
    '🦸‍♀' => 'kvinneleg superhelt',
    '🦹‍♂' => 'mannleg superskurk',
    '🦹‍♀' => 'kvinneleg superskurk',
    '🧚‍♂' => 'mannleg fe',
    '🧚‍♀' => 'kvinneleg fe',
    '🧛‍♂' => 'mannleg vampyr',
    '🧛‍♀' => 'kvinneleg vampyr',
    '🧝‍♂' => 'mannleg alv',
    '🧝‍♀' => 'kvinneleg alv',
    '🧞‍♂' => 'mannleg ånd',
    '🧞‍♀' => 'kvinneleg ånd',
    '🧟‍♂' => 'mannleg zombie',
    '🧟‍♀' => 'kvinneleg zombie',
    '💆‍♂' => 'mann som får andletsmassasje',
    '💆‍♀' => 'kvinne som får andletsmassasje',
    '🚶‍♂' => 'mannleg fotgjengar',
    '🚶‍♀' => 'kvinneleg fotgjengar',
    '🏃‍♂' => 'mannleg løpar',
    '🏃‍♀' => 'kvineleg løpar',
    '🧑‍🩰' => 'ballettdansar',
    '👯‍♂' => 'menn med kaninøyre',
    '👯‍♀' => 'kvinner med kaninøyre',
    '🧖‍♂' => 'mann i badstove',
    '🧖‍♀' => 'kvinne i badstove',
    '🧗‍♂' => 'mannleg klatrar',
    '🧗‍♀' => 'kvinneleg klatrar',
    '🏌‍♂' => 'mannleg golfspelar',
    '🏌‍♀' => 'kvinneleg golfspelar',
    '🏄‍♂' => 'mannleg surfar',
    '🏄‍♀' => 'kvinneleg surfar',
    '🏊‍♂' => 'mannleg symjar',
    '🏊‍♀' => 'kvinneleg symjar',
    '🏋‍♂' => 'mannleg vektløftar',
    '🏋‍♀' => 'kvinneleg vektløftar',
    '🚴‍♂' => 'mannleg syklist',
    '🚴‍♀' => 'kvinneleg syklist',
    '🤼‍♂' => 'mannlege brytarar',
    '🤼‍♀' => 'kvinnelege brytarar',
    '🤽‍♂' => 'mannleg vasspolospelar',
    '🤽‍♀' => 'kvinneleg vasspolospelar',
    '🤾‍♂' => 'mannleg handballspelar',
    '🤾‍♀' => 'kvinneleg handballspelar',
    '🤹‍♂' => 'mannleg sjonglør',
    '🤹‍♀' => 'kvinneleg sjonglør',
    '🧑‍🧒' => 'familie: vaksen, barn',
    '⛓‍💥' => 'broten lenke',
    '🏳‍🌈' => 'regnbogeflagg',
    '🏴‍☠' => 'sjørøvarflagg',
    '👋🏻' => 'vinkande hand: hudtype 1–2',
    '👋🏼' => 'vinkande hand: hudtype 3',
    '👋🏽' => 'vinkande hand: hudtype 4',
    '👋🏾' => 'vinkande hand: hudtype 5',
    '👋🏿' => 'vinkande hand: hudtype 6',
    '🤚🏻' => 'løfta handbak: hudtype 1–2',
    '🤚🏼' => 'løfta handbak: hudtype 3',
    '🤚🏽' => 'løfta handbak: hudtype 4',
    '🤚🏾' => 'løfta handbak: hudtype 5',
    '🤚🏿' => 'løfta handbak: hudtype 6',
    '🖐🏻' => 'flat hand med spreidde fingrar: hudtype 1–2',
    '🖐🏼' => 'flat hand med spreidde fingrar: hudtype 3',
    '🖐🏽' => 'flat hand med spreidde fingrar: hudtype 4',
    '🖐🏾' => 'flat hand med spreidde fingrar: hudtype 5',
    '🖐🏿' => 'flat hand med spreidde fingrar: hudtype 6',
    '✋🏻' => 'heva hand: hudtype 1–2',
    '✋🏼' => 'heva hand: hudtype 3',
    '✋🏽' => 'heva hand: hudtype 4',
    '✋🏾' => 'heva hand: hudtype 5',
    '✋🏿' => 'heva hand: hudtype 6',
    '🖖🏻' => 'Vulcan-helsing: hudtype 1–2',
    '🖖🏼' => 'Vulcan-helsing: hudtype 3',
    '🖖🏽' => 'Vulcan-helsing: hudtype 4',
    '🖖🏾' => 'Vulcan-helsing: hudtype 5',
    '🖖🏿' => 'Vulcan-helsing: hudtype 6',
    '🫱🏻' => 'hand mot høgre: hudtype 1–2',
    '🫱🏼' => 'hand mot høgre: hudtype 3',
    '🫱🏽' => 'hand mot høgre: hudtype 4',
    '🫱🏾' => 'hand mot høgre: hudtype 5',
    '🫱🏿' => 'hand mot høgre: hudtype 6',
    '🫲🏻' => 'hand mot venstre: hudtype 1–2',
    '🫲🏼' => 'hand mot venstre: hudtype 3',
    '🫲🏽' => 'hand mot venstre: hudtype 4',
    '🫲🏾' => 'hand mot venstre: hudtype 5',
    '🫲🏿' => 'hand mot venstre: hudtype 6',
    '🫳🏻' => 'handflata ned: hudtype 1–2',
    '🫳🏼' => 'handflata ned: hudtype 3',
    '🫳🏽' => 'handflata ned: hudtype 4',
    '🫳🏾' => 'handflata ned: hudtype 5',
    '🫳🏿' => 'handflata ned: hudtype 6',
    '🫴🏻' => 'handflata opp: hudtype 1–2',
    '🫴🏼' => 'handflata opp: hudtype 3',
    '🫴🏽' => 'handflata opp: hudtype 4',
    '🫴🏾' => 'handflata opp: hudtype 5',
    '🫴🏿' => 'handflata opp: hudtype 6',
    '🫷🏻' => 'handflate heva mot venstre: hudtype 1–2',
    '🫷🏼' => 'handflate heva mot venstre: hudtype 3',
    '🫷🏽' => 'handflate heva mot venstre: hudtype 4',
    '🫷🏾' => 'handflate heva mot venstre: hudtype 5',
    '🫷🏿' => 'handflate heva mot venstre: hudtype 6',
    '🫸🏻' => 'handflate heva mot høgre: hudtype 1–2',
    '🫸🏼' => 'handflate heva mot høgre: hudtype 3',
    '🫸🏽' => 'handflate heva mot høgre: hudtype 4',
    '🫸🏾' => 'handflate heva mot høgre: hudtype 5',
    '🫸🏿' => 'handflate heva mot høgre: hudtype 6',
    '👌🏻' => 'OK-hand: hudtype 1–2',
    '👌🏼' => 'OK-hand: hudtype 3',
    '👌🏽' => 'OK-hand: hudtype 4',
    '👌🏾' => 'OK-hand: hudtype 5',
    '👌🏿' => 'OK-hand: hudtype 6',
    '🤌🏻' => 'hand med fingertuppane saman: hudtype 1–2',
    '🤌🏼' => 'hand med fingertuppane saman: hudtype 3',
    '🤌🏽' => 'hand med fingertuppane saman: hudtype 4',
    '🤌🏾' => 'hand med fingertuppane saman: hudtype 5',
    '🤌🏿' => 'hand med fingertuppane saman: hudtype 6',
    '🤏🏻' => 'hand som klyp: hudtype 1–2',
    '🤏🏼' => 'hand som klyp: hudtype 3',
    '🤏🏽' => 'hand som klyp: hudtype 4',
    '🤏🏾' => 'hand som klyp: hudtype 5',
    '🤏🏿' => 'hand som klyp: hudtype 6',
    '✌🏻' => 'seiersteikn: hudtype 1–2',
    '✌🏼' => 'seiersteikn: hudtype 3',
    '✌🏽' => 'seiersteikn: hudtype 4',
    '✌🏾' => 'seiersteikn: hudtype 5',
    '✌🏿' => 'seiersteikn: hudtype 6',
    '🤞🏻' => 'kryssande fingrar: hudtype 1–2',
    '🤞🏼' => 'kryssande fingrar: hudtype 3',
    '🤞🏽' => 'kryssande fingrar: hudtype 4',
    '🤞🏾' => 'kryssande fingrar: hudtype 5',
    '🤞🏿' => 'kryssande fingrar: hudtype 6',
    '🫰🏻' => 'hand med peikefinger og tommel kryssa: hudtype 1–2',
    '🫰🏼' => 'hand med peikefinger og tommel kryssa: hudtype 3',
    '🫰🏽' => 'hand med peikefinger og tommel kryssa: hudtype 4',
    '🫰🏾' => 'hand med peikefinger og tommel kryssa: hudtype 5',
    '🫰🏿' => 'hand med peikefinger og tommel kryssa: hudtype 6',
    '🤟🏻' => 'glad i deg-teikn: hudtype 1–2',
    '🤟🏼' => 'glad i deg-teikn: hudtype 3',
    '🤟🏽' => 'glad i deg-teikn: hudtype 4',
    '🤟🏾' => 'glad i deg-teikn: hudtype 5',
    '🤟🏿' => 'glad i deg-teikn: hudtype 6',
    '🤙🏻' => 'ring meg-hand: hudtype 1–2',
    '🤙🏼' => 'ring meg-hand: hudtype 3',
    '🤙🏽' => 'ring meg-hand: hudtype 4',
    '🤙🏾' => 'ring meg-hand: hudtype 5',
    '🤙🏿' => 'ring meg-hand: hudtype 6',
    '👈🏻' => 'peikar mot venstre – bakhand: hudtype 1–2',
    '👈🏼' => 'peikar mot venstre – bakhand: hudtype 3',
    '👈🏽' => 'peikar mot venstre – bakhand: hudtype 4',
    '👈🏾' => 'peikar mot venstre – bakhand: hudtype 5',
    '👈🏿' => 'peikar mot venstre – bakhand: hudtype 6',
    '👉🏻' => 'peikar mot høgre – bakhand: hudtype 1–2',
    '👉🏼' => 'peikar mot høgre – bakhand: hudtype 3',
    '👉🏽' => 'peikar mot høgre – bakhand: hudtype 4',
    '👉🏾' => 'peikar mot høgre – bakhand: hudtype 5',
    '👉🏿' => 'peikar mot høgre – bakhand: hudtype 6',
    '👆🏻' => 'peikar opp – bakhand: hudtype 1–2',
    '👆🏼' => 'peikar opp – bakhand: hudtype 3',
    '👆🏽' => 'peikar opp – bakhand: hudtype 4',
    '👆🏾' => 'peikar opp – bakhand: hudtype 5',
    '👆🏿' => 'peikar opp – bakhand: hudtype 6',
    '👇🏻' => 'peikar ned – bakhand: hudtype 1–2',
    '👇🏼' => 'peikar ned – bakhand: hudtype 3',
    '👇🏽' => 'peikar ned – bakhand: hudtype 4',
    '👇🏾' => 'peikar ned – bakhand: hudtype 5',
    '👇🏿' => 'peikar ned – bakhand: hudtype 6',
    '☝🏻' => 'peikar opp: hudtype 1–2',
    '☝🏼' => 'peikar opp: hudtype 3',
    '☝🏽' => 'peikar opp: hudtype 4',
    '☝🏾' => 'peikar opp: hudtype 5',
    '☝🏿' => 'peikar opp: hudtype 6',
    '🫵🏻' => 'peikefinger peiker på lesaren: hudtype 1–2',
    '🫵🏼' => 'peikefinger peiker på lesaren: hudtype 3',
    '🫵🏽' => 'peikefinger peiker på lesaren: hudtype 4',
    '🫵🏾' => 'peikefinger peiker på lesaren: hudtype 5',
    '🫵🏿' => 'peikefinger peiker på lesaren: hudtype 6',
    '✊🏻' => 'heva knyttneve: hudtype 1–2',
    '✊🏼' => 'heva knyttneve: hudtype 3',
    '✊🏽' => 'heva knyttneve: hudtype 4',
    '✊🏾' => 'heva knyttneve: hudtype 5',
    '✊🏿' => 'heva knyttneve: hudtype 6',
    '🤜🏻' => 'knyttneve mot høgre: hudtype 1–2',
    '🤜🏼' => 'knyttneve mot høgre: hudtype 3',
    '🤜🏽' => 'knyttneve mot høgre: hudtype 4',
    '🤜🏾' => 'knyttneve mot høgre: hudtype 5',
    '🤜🏿' => 'knyttneve mot høgre: hudtype 6',
    '👏🏻' => 'klappande hender: hudtype 1–2',
    '👏🏼' => 'klappande hender: hudtype 3',
    '👏🏽' => 'klappande hender: hudtype 4',
    '👏🏾' => 'klappande hender: hudtype 5',
    '👏🏿' => 'klappande hender: hudtype 6',
    '🙌🏻' => 'heva hender: hudtype 1–2',
    '🙌🏼' => 'heva hender: hudtype 3',
    '🙌🏽' => 'heva hender: hudtype 4',
    '🙌🏾' => 'heva hender: hudtype 5',
    '🙌🏿' => 'heva hender: hudtype 6',
    '🫶🏻' => 'hjartehender: hudtype 1–2',
    '🫶🏼' => 'hjartehender: hudtype 3',
    '🫶🏽' => 'hjartehender: hudtype 4',
    '🫶🏾' => 'hjartehender: hudtype 5',
    '🫶🏿' => 'hjartehender: hudtype 6',
    '👐🏻' => 'opne hender: hudtype 1–2',
    '👐🏼' => 'opne hender: hudtype 3',
    '👐🏽' => 'opne hender: hudtype 4',
    '👐🏾' => 'opne hender: hudtype 5',
    '👐🏿' => 'opne hender: hudtype 6',
    '🤲🏻' => 'handflatene saman: hudtype 1–2',
    '🤲🏼' => 'handflatene saman: hudtype 3',
    '🤲🏽' => 'handflatene saman: hudtype 4',
    '🤲🏾' => 'handflatene saman: hudtype 5',
    '🤲🏿' => 'handflatene saman: hudtype 6',
    '🤝🏻' => 'handhelse: hudtype 1–2',
    '🤝🏼' => 'handhelse: hudtype 3',
    '🤝🏽' => 'handhelse: hudtype 4',
    '🤝🏾' => 'handhelse: hudtype 5',
    '🤝🏿' => 'handhelse: hudtype 6',
    '🙏🏻' => 'falda hender: hudtype 1–2',
    '🙏🏼' => 'falda hender: hudtype 3',
    '🙏🏽' => 'falda hender: hudtype 4',
    '🙏🏾' => 'falda hender: hudtype 5',
    '🙏🏿' => 'falda hender: hudtype 6',
    '✍🏻' => 'skrivande hand: hudtype 1–2',
    '✍🏼' => 'skrivande hand: hudtype 3',
    '✍🏽' => 'skrivande hand: hudtype 4',
    '✍🏾' => 'skrivande hand: hudtype 5',
    '✍🏿' => 'skrivande hand: hudtype 6',
    '💅🏻' => 'naglelakk: hudtype 1–2',
    '💅🏼' => 'naglelakk: hudtype 3',
    '💅🏽' => 'naglelakk: hudtype 4',
    '💅🏾' => 'naglelakk: hudtype 5',
    '💅🏿' => 'naglelakk: hudtype 6',
    '👂🏻' => 'øyre: hudtype 1–2',
    '👂🏼' => 'øyre: hudtype 3',
    '👂🏽' => 'øyre: hudtype 4',
    '👂🏾' => 'øyre: hudtype 5',
    '👂🏿' => 'øyre: hudtype 6',
    '🦻🏻' => 'øyre med høyreapparat: hudtype 1–2',
    '🦻🏼' => 'øyre med høyreapparat: hudtype 3',
    '🦻🏽' => 'øyre med høyreapparat: hudtype 4',
    '🦻🏾' => 'øyre med høyreapparat: hudtype 5',
    '🦻🏿' => 'øyre med høyreapparat: hudtype 6',
    '👃🏻' => 'nase: hudtype 1–2',
    '👃🏼' => 'nase: hudtype 3',
    '👃🏽' => 'nase: hudtype 4',
    '👃🏾' => 'nase: hudtype 5',
    '👃🏿' => 'nase: hudtype 6',
    '👦🏻' => 'gut: hudtype 1–2',
    '👦🏼' => 'gut: hudtype 3',
    '👦🏽' => 'gut: hudtype 4',
    '👦🏾' => 'gut: hudtype 5',
    '👦🏿' => 'gut: hudtype 6',
    '🧑🏻' => 'vaksen: hudtype 1–2',
    '🧑🏼' => 'vaksen: hudtype 3',
    '🧑🏽' => 'vaksen: hudtype 4',
    '🧑🏾' => 'vaksen: hudtype 5',
    '🧑🏿' => 'vaksen: hudtype 6',
    '🧓🏻' => 'eldre vaksen: hudtype 1–2',
    '🧓🏼' => 'eldre vaksen: hudtype 3',
    '🧓🏽' => 'eldre vaksen: hudtype 4',
    '🧓🏾' => 'eldre vaksen: hudtype 5',
    '🧓🏿' => 'eldre vaksen: hudtype 6',
    '🙍🏻' => 'rynkar bryna: hudtype 1–2',
    '🙍🏼' => 'rynkar bryna: hudtype 3',
    '🙍🏽' => 'rynkar bryna: hudtype 4',
    '🙍🏾' => 'rynkar bryna: hudtype 5',
    '🙍🏿' => 'rynkar bryna: hudtype 6',
    '🙎🏻' => 'furtar: hudtype 1–2',
    '🙎🏼' => 'furtar: hudtype 3',
    '🙎🏽' => 'furtar: hudtype 4',
    '🙎🏾' => 'furtar: hudtype 5',
    '🙎🏿' => 'furtar: hudtype 6',
    '💁🏻' => 'hjelpande person: hudtype 1–2',
    '💁🏼' => 'hjelpande person: hudtype 3',
    '💁🏽' => 'hjelpande person: hudtype 4',
    '💁🏾' => 'hjelpande person: hudtype 5',
    '💁🏿' => 'hjelpande person: hudtype 6',
    '🙋🏻' => 'rekker opp handa: hudtype 1–2',
    '🙋🏼' => 'rekker opp handa: hudtype 3',
    '🙋🏽' => 'rekker opp handa: hudtype 4',
    '🙋🏾' => 'rekker opp handa: hudtype 5',
    '🙋🏿' => 'rekker opp handa: hudtype 6',
    '🙇🏻' => 'bukkar: hudtype 1–2',
    '🙇🏼' => 'bukkar: hudtype 3',
    '🙇🏽' => 'bukkar: hudtype 4',
    '🙇🏾' => 'bukkar: hudtype 5',
    '🙇🏿' => 'bukkar: hudtype 6',
    '🤦🏻' => 'slår handa mot panna: hudtype 1–2',
    '🤦🏼' => 'slår handa mot panna: hudtype 3',
    '🤦🏽' => 'slår handa mot panna: hudtype 4',
    '🤦🏾' => 'slår handa mot panna: hudtype 5',
    '🤦🏿' => 'slår handa mot panna: hudtype 6',
    '🤷🏻' => 'trekkjer på skuldrene: hudtype 1–2',
    '🤷🏼' => 'trekkjer på skuldrene: hudtype 3',
    '🤷🏽' => 'trekkjer på skuldrene: hudtype 4',
    '🤷🏾' => 'trekkjer på skuldrene: hudtype 5',
    '🤷🏿' => 'trekkjer på skuldrene: hudtype 6',
    '👷🏻' => 'anleggsarbeidar: hudtype 1–2',
    '👷🏼' => 'anleggsarbeidar: hudtype 3',
    '👷🏽' => 'anleggsarbeidar: hudtype 4',
    '👷🏾' => 'anleggsarbeidar: hudtype 5',
    '👷🏿' => 'anleggsarbeidar: hudtype 6',
    '🧕🏻' => 'kvinne med hovudslør: hudtype 1–2',
    '🧕🏼' => 'kvinne med hovudslør: hudtype 3',
    '🧕🏽' => 'kvinne med hovudslør: hudtype 4',
    '🧕🏾' => 'kvinne med hovudslør: hudtype 5',
    '🧕🏿' => 'kvinne med hovudslør: hudtype 6',
    '🤱🏻' => 'ammar: hudtype 1–2',
    '🤱🏼' => 'ammar: hudtype 3',
    '🤱🏽' => 'ammar: hudtype 4',
    '🤱🏾' => 'ammar: hudtype 5',
    '🤱🏿' => 'ammar: hudtype 6',
    '💆🏻' => 'andletsmassasje: hudtype 1–2',
    '💆🏼' => 'andletsmassasje: hudtype 3',
    '💆🏽' => 'andletsmassasje: hudtype 4',
    '💆🏾' => 'andletsmassasje: hudtype 5',
    '💆🏿' => 'andletsmassasje: hudtype 6',
    '🚶🏻' => 'fotgjengar: hudtype 1–2',
    '🚶🏼' => 'fotgjengar: hudtype 3',
    '🚶🏽' => 'fotgjengar: hudtype 4',
    '🚶🏾' => 'fotgjengar: hudtype 5',
    '🚶🏿' => 'fotgjengar: hudtype 6',
    '🏃🏻' => 'løpar: hudtype 1–2',
    '🏃🏼' => 'løpar: hudtype 3',
    '🏃🏽' => 'løpar: hudtype 4',
    '🏃🏾' => 'løpar: hudtype 5',
    '🏃🏿' => 'løpar: hudtype 6',
    '💃🏻' => 'dansande kvinne: hudtype 1–2',
    '💃🏼' => 'dansande kvinne: hudtype 3',
    '💃🏽' => 'dansande kvinne: hudtype 4',
    '💃🏾' => 'dansande kvinne: hudtype 5',
    '💃🏿' => 'dansande kvinne: hudtype 6',
    '🕺🏻' => 'dansande mann: hudtype 1–2',
    '🕺🏼' => 'dansande mann: hudtype 3',
    '🕺🏽' => 'dansande mann: hudtype 4',
    '🕺🏾' => 'dansande mann: hudtype 5',
    '🕺🏿' => 'dansande mann: hudtype 6',
    '🕴🏻' => 'svevande mann i dress: hudtype 1–2',
    '🕴🏼' => 'svevande mann i dress: hudtype 3',
    '🕴🏽' => 'svevande mann i dress: hudtype 4',
    '🕴🏾' => 'svevande mann i dress: hudtype 5',
    '🕴🏿' => 'svevande mann i dress: hudtype 6',
    '👯🏻' => 'personar med kaninøyre: hudtype 1–2',
    '👯🏼' => 'personar med kaninøyre: hudtype 3',
    '👯🏽' => 'personar med kaninøyre: hudtype 4',
    '👯🏾' => 'personar med kaninøyre: hudtype 5',
    '👯🏿' => 'personar med kaninøyre: hudtype 6',
    '🧖🏻' => 'person i badstove: hudtype 1–2',
    '🧖🏼' => 'person i badstove: hudtype 3',
    '🧖🏽' => 'person i badstove: hudtype 4',
    '🧖🏾' => 'person i badstove: hudtype 5',
    '🧖🏿' => 'person i badstove: hudtype 6',
    '🧗🏻' => 'klatrar: hudtype 1–2',
    '🧗🏼' => 'klatrar: hudtype 3',
    '🧗🏽' => 'klatrar: hudtype 4',
    '🧗🏾' => 'klatrar: hudtype 5',
    '🧗🏿' => 'klatrar: hudtype 6',
    '🏂🏻' => 'snøbrettkøyrar: hudtype 1–2',
    '🏂🏼' => 'snøbrettkøyrar: hudtype 3',
    '🏂🏽' => 'snøbrettkøyrar: hudtype 4',
    '🏂🏾' => 'snøbrettkøyrar: hudtype 5',
    '🏂🏿' => 'snøbrettkøyrar: hudtype 6',
    '🏌🏻' => 'golfspelar: hudtype 1–2',
    '🏌🏼' => 'golfspelar: hudtype 3',
    '🏌🏽' => 'golfspelar: hudtype 4',
    '🏌🏾' => 'golfspelar: hudtype 5',
    '🏌🏿' => 'golfspelar: hudtype 6',
    '🏄🏻' => 'surfar: hudtype 1–2',
    '🏄🏼' => 'surfar: hudtype 3',
    '🏄🏽' => 'surfar: hudtype 4',
    '🏄🏾' => 'surfar: hudtype 5',
    '🏄🏿' => 'surfar: hudtype 6',
    '🏊🏻' => 'symjar: hudtype 1–2',
    '🏊🏼' => 'symjar: hudtype 3',
    '🏊🏽' => 'symjar: hudtype 4',
    '🏊🏾' => 'symjar: hudtype 5',
    '🏊🏿' => 'symjar: hudtype 6',
    '🏋🏻' => 'vektløftar: hudtype 1–2',
    '🏋🏼' => 'vektløftar: hudtype 3',
    '🏋🏽' => 'vektløftar: hudtype 4',
    '🏋🏾' => 'vektløftar: hudtype 5',
    '🏋🏿' => 'vektløftar: hudtype 6',
    '🤼🏻' => 'brytarar: hudtype 1–2',
    '🤼🏼' => 'brytarar: hudtype 3',
    '🤼🏽' => 'brytarar: hudtype 4',
    '🤼🏾' => 'brytarar: hudtype 5',
    '🤼🏿' => 'brytarar: hudtype 6',
    '🤽🏻' => 'vasspolo: hudtype 1–2',
    '🤽🏼' => 'vasspolo: hudtype 3',
    '🤽🏽' => 'vasspolo: hudtype 4',
    '🤽🏾' => 'vasspolo: hudtype 5',
    '🤽🏿' => 'vasspolo: hudtype 6',
    '🤾🏻' => 'handball: hudtype 1–2',
    '🤾🏼' => 'handball: hudtype 3',
    '🤾🏽' => 'handball: hudtype 4',
    '🤾🏾' => 'handball: hudtype 5',
    '🤾🏿' => 'handball: hudtype 6',
    '👭🏻' => 'kvinner som leiar: hudtype 1–2',
    '👭🏼' => 'kvinner som leiar: hudtype 3',
    '👭🏽' => 'kvinner som leiar: hudtype 4',
    '👭🏾' => 'kvinner som leiar: hudtype 5',
    '👭🏿' => 'kvinner som leiar: hudtype 6',
    '👫🏻' => 'mann og kvinne som leiar: hudtype 1–2',
    '👫🏼' => 'mann og kvinne som leiar: hudtype 3',
    '👫🏽' => 'mann og kvinne som leiar: hudtype 4',
    '👫🏾' => 'mann og kvinne som leiar: hudtype 5',
    '👫🏿' => 'mann og kvinne som leiar: hudtype 6',
    '👬🏻' => 'menn som leiar: hudtype 1–2',
    '👬🏼' => 'menn som leiar: hudtype 3',
    '👬🏽' => 'menn som leiar: hudtype 4',
    '👬🏾' => 'menn som leiar: hudtype 5',
    '👬🏿' => 'menn som leiar: hudtype 6',
    '💑🏻' => 'par med hjarte: hudtype 1–2',
    '💑🏼' => 'par med hjarte: hudtype 3',
    '💑🏽' => 'par med hjarte: hudtype 4',
    '💑🏾' => 'par med hjarte: hudtype 5',
    '💑🏿' => 'par med hjarte: hudtype 6',
    '🇦🇪' => 'flagg: Dei sameinte arabiske emirata',
    '🇦🇹' => 'flagg: Austerrike',
    '🇨🇨' => 'flagg: Kokosøyane',
    '🇨🇩' => 'flagg: Kongo-Kinshasa',
    '🇨🇫' => 'flagg: Den sentralafrikanske republikken',
    '🇨🇮' => 'flagg: Elfenbeinskysten',
    '🇨🇰' => 'flagg: Cookøyane',
    '🇩🇴' => 'flagg: Den dominikanske republikken',
    '🇪🇺' => 'flagg: Den europeiske unionen',
    '🇫🇰' => 'flagg: Falklandsøyane',
    '🇫🇴' => 'flagg: Færøyane',
    '🇬🇸' => 'flagg: Sør-Georgia og Sør-Sandwichøyane',
    '🇭🇲' => 'flagg: Heardøya og McDonaldøyane',
    '🇮🇨' => 'flagg: Kanariøyane',
    '🇰🇲' => 'flagg: Komorane',
    '🇰🇾' => 'flagg: Caymanøyane',
    '🇱🇺' => 'flagg: Luxembourg',
    '🇲🇭' => 'flagg: Marshalløyane',
    '🇲🇵' => 'flagg: Nord-Marianane',
    '🇲🇻' => 'flagg: Maldivane',
    '🇳🇴' => 'flagg: Noreg',
    '🇵🇭' => 'flagg: Filippinane',
    '🇵🇳' => 'flagg: Pitcairn',
    '🇸🇧' => 'flagg: Salomonøyane',
    '🇸🇨' => 'flagg: Seychellane',
    '🇸🇭' => 'flagg: Saint Helena',
    '🇹🇨' => 'flagg: Turks- og Caicosøyane',
    '🇹🇫' => 'flagg: Dei franske sørterritoria',
    '🇹🇱' => 'flagg: Aust-Timor',
    '🇺🇲' => 'flagg: USAs ytre småøyar',
    '🇺🇳' => 'flagg: Dei sameinte nasjonane',
    '🇻🇨' => 'flagg: St. Vincent og Grenadinane',
    '🇻🇬' => 'flagg: Dei britiske Jomfruøyane',
    '🇻🇮' => 'flagg: Dei amerikanske Jomfruøyane',
    '🔟' => 'tastar: 10',
    '😃' => 'glisande fjes med vidopne auge',
    '😄' => 'smilefjes med open munn og smilande auge',
    '😁' => 'glisefjes med smilande auge',
    '😆' => 'smil med samanknipne auge',
    '😅' => 'glisande fjes som sveittar',
    '🤣' => 'rullar rundt på golvet i latter',
    '🙂' => 'fjes som smiler litt',
    '🫠' => 'fjes som smeltar',
    '😉' => 'blunkande fjes',
    '😊' => 'smil med smilande auge',
    '🥰' => 'smilefjes med hjarte',
    '😍' => 'smilefjes med hjarteauge',
    '🤩' => 'stjerner i auga',
    '😚' => 'kyss med lukka auge',
    '😙' => 'kyss med smilande auge',
    '😛' => 'rekkjer tunge',
    '😜' => 'blunkar og rekkjer tunge',
    '🤪' => 'galen',
    '🤑' => 'pengegalen',
    '🤗' => 'fjes som gjev klem',
    '🤭' => 'handa over munnen',
    '🫢' => 'fjes med opne auge og hand over munnen',
    '🫣' => 'fjes som kikkar fram bak hendene',
    '🤔' => 'tenkjefjes',
    '🤨' => 'heva augebryn',
    '😑' => 'uttrykkslaus',
    '😶' => 'utan munn',
    '🫥' => 'fjes med stipla omriss',
    '😒' => 'misnøgd',
    '🙄' => 'himlar med auga',
    '🤥' => 'lyg',
    '🫨' => 'skjelvande fjes',
    '😌' => 'letta',
    '🤤' => 'siklar',
    '😴' => 'søv',
    '🫩' => 'fjes med posar under auga',
    '🤕' => 'bandasjert hovud',
    '🤮' => 'kastar opp',
    '🤧' => 'nys',
    '🤯' => 'eksploderande hovud',
    '🥸' => 'fjes med forkleding',
    '😕' => 'forvirra',
    '😟' => 'bekymra',
    '😮' => 'forbausa',
    '😯' => 'overraska',
    '😳' => 'raudnar',
    '🫪' => 'fordreidd fjes',
    '🥺' => 'bedande fjes',
    '🥹' => 'fjes som held tilbake tårene',
    '😦' => 'oppgjeven',
    '😰' => 'engsteleg og sveittar',
    '😢' => 'græt',
    '😭' => 'strigræt',
    '😖' => 'fortvila',
    '😞' => 'skuffa',
    '😓' => 'kaldsveittar',
    '😫' => 'trøytt fjes',
    '🥱' => 'geispande fjes',
    '😤' => 'triumferande',
    '😡' => 'rasande',
    '🤬' => 'fjes med symbol over munnen',
    '😈' => 'smilande djevel',
    '💀' => 'hovudskalle',
    '☠' => 'daudinghovud',
    '😺' => 'smilande katt med open munn',
    '😸' => 'flirande katt med smilande auge',
    '😻' => 'smilande katt med hjarteauge',
    '😽' => 'kyssande katt',
    '😿' => 'gråtande katt',
    '😾' => 'surmulande katt',
    '🙈' => 'ser ingenting vondt',
    '🙉' => 'høyrer ingenting vondt',
    '🙊' => 'seier ingenting vondt',
    '💌' => 'kjærleiksbrev',
    '💘' => 'hjarte med pil',
    '💝' => 'hjarte med band',
    '💖' => 'skinande hjarte',
    '💗' => 'veksande hjarte',
    '💓' => 'bankande hjarte',
    '💞' => 'snurrande hjarte',
    '💕' => 'to hjarte',
    '💟' => 'hjartedekorasjon',
    '❣' => 'utropsteikn med hjarte',
    '💔' => 'knust hjarte',
    '❤' => 'raudt hjarte',
    '🩷' => 'rosa hjarte',
    '🧡' => 'oransje hjarte',
    '💛' => 'gult hjarte',
    '💚' => 'grønt hjarte',
    '💙' => 'blått hjarte',
    '🩵' => 'lyseblått hjarte',
    '💜' => 'lilla hjarte',
    '🤎' => 'brunt hjarte',
    '🖤' => 'svart hjarte',
    '🩶' => 'grått hjarte',
    '🤍' => 'kvitt hjarte',
    '💦' => 'sveittedropar',
    '💨' => 'stikk av',
    '🕳' => 'hol i bakken',
    '🗯' => 'sint snakkeboble mot høgre',
    '👋' => 'vinkande hand',
    '🤚' => 'løfta handbak',
    '🖐' => 'flat hand med spreidde fingrar',
    '✋' => 'heva hand',
    '🖖' => 'Vulcan-helsing',
    '🫱' => 'hand mot høgre',
    '🫲' => 'hand mot venstre',
    '🫳' => 'handflata ned',
    '🫴' => 'handflata opp',
    '🫷' => 'handflate heva mot venstre',
    '🫸' => 'handflate heva mot høgre',
    '👌' => 'OK-hand',
    '🤌' => 'hand med fingertuppane saman',
    '🤏' => 'hand som klyp',
    '✌' => 'seiersteikn',
    '🤞' => 'kryssande fingrar',
    '🫰' => 'hand med peikefinger og tommel kryssa',
    '🤟' => 'glad i deg-teikn',
    '🤙' => 'ring meg-hand',
    '👈' => 'peikar mot venstre – bakhand',
    '👉' => 'peikar mot høgre – bakhand',
    '👆' => 'peikar opp – bakhand',
    '👇' => 'peikar ned – bakhand',
    '☝' => 'peikar opp',
    '🫵' => 'peikefinger peiker på lesaren',
    '✊' => 'heva knyttneve',
    '🤜' => 'knyttneve mot høgre',
    '👏' => 'klappande hender',
    '🙌' => 'heva hender',
    '🫶' => 'hjartehender',
    '👐' => 'opne hender',
    '🤲' => 'handflatene saman',
    '🤝' => 'handhelse',
    '🙏' => 'falda hender',
    '✍' => 'skrivande hand',
    '💅' => 'naglelakk',
    '👂' => 'øyre',
    '🦻' => 'øyre med høyreapparat',
    '👃' => 'nase',
    '🫀' => 'hjartemuskel',
    '👀' => 'auge',
    '👁' => 'auga',
    '🫦' => 'bite seg i leppa',
    '👦' => 'gut',
    '🧑' => 'vaksen',
    '🧓' => 'eldre vaksen',
    '🙍' => 'rynkar bryna',
    '🙎' => 'furtar',
    '💁' => 'hjelpande person',
    '🙋' => 'rekker opp handa',
    '🙇' => 'bukkar',
    '🤦' => 'slår handa mot panna',
    '🤷' => 'trekkjer på skuldrene',
    '👷' => 'anleggsarbeidar',
    '🧕' => 'kvinne med hovudslør',
    '🤱' => 'ammar',
    '💆' => 'andletsmassasje',
    '🚶' => 'fotgjengar',
    '🏃' => 'løpar',
    '💃' => 'dansande kvinne',
    '🕺' => 'dansande mann',
    '🕴' => 'svevande mann i dress',
    '👯' => 'personar med kaninøyre',
    '🧖' => 'person i badstove',
    '🧗' => 'klatrar',
    '🤺' => 'fektar',
    '⛷' => 'skiløpar',
    '🏂' => 'snøbrettkøyrar',
    '🏌' => 'golfspelar',
    '🏄' => 'surfar',
    '🏊' => 'symjar',
    '🏋' => 'vektløftar',
    '🤼' => 'brytarar',
    '🤽' => 'vasspolo',
    '🤾' => 'handball',
    '👭' => 'kvinner som leiar',
    '👫' => 'mann og kvinne som leiar',
    '👬' => 'menn som leiar',
    '💑' => 'par med hjarte',
    '🗣' => 'snakkande hovud i profil',
    '🦰' => 'raudt hår',
    '🦱' => 'krusete hår',
    '🦲' => 'skalla',
    '🦮' => 'førarhund',
    '🦄' => 'einhjørning',
    '🐃' => 'vassbøffel',
    '🦏' => 'nashorn',
    '🦔' => 'piggsvin',
    '🐣' => 'nyklekt kylling',
    '🐥' => 'kylling framanfrå',
    '🪶' => 'fjør',
    '🪽' => 'venge',
    '🐢' => 'skjelpadde',
    '🐲' => 'drakefjes',
    '🐉' => 'drake',
    '🐳' => 'sprutande kval',
    '🐋' => 'kval',
    '🫍' => 'spekkhoggar',
    '🐚' => 'spiralskjel',
    '🦞' => 'hummar',
    '🐌' => 'snigel',
    '🦋' => 'sommarfugl',
    '🦗' => 'grashoppe',
    '🪰' => 'floge',
    '🌸' => 'kirsebærblomster',
    '💮' => 'kvit blomster',
    '🪷' => 'lotusblomster',
    '🥀' => 'vissen blomster',
    '🌼' => 'blomster',
    '🌳' => 'lauvtre',
    '🌿' => 'urteblad',
    '🍂' => 'haustblad',
    '🍃' => 'blad i vind',
    '🪹' => 'tomt reir',
    '🪺' => 'reir med egg',
    '🪾' => 'bladlaust tre',
    '🍉' => 'vassmelon',
    '🍎' => 'raudt eple',
    '🌶' => 'raud chili',
    '🥬' => 'bladgrønsaker',
    '🧄' => 'kvitlauk',
    '🧅' => 'lauk',
    '🫜' => 'rotgrønsak',
    '🍖' => 'kjøt med bein',
    '🥩' => 'kjøtstykke',
    '🍔' => 'hamburgar',
    '🥘' => 'låg gryte med mat',
    '🥣' => 'bolle med skei',
    '🥗' => 'grøn salat',
    '🍜' => 'matbolle som dampar',
    '🍦' => 'softis',
    '🍭' => 'slikkepinne',
    '🥛' => 'mjølkeglas',
    '🍷' => 'vinglas',
    '🍸' => 'cocktailglas',
    '🥂' => 'glas som skåler',
    '🥃' => 'whiskyglas',
    '🥤' => 'kopp med sugerøyr',
    '🥢' => 'spisepinnar',
    '🥄' => 'skei',
    '🌐' => 'jordklode med meridianar',
    '🗺' => 'verdskart',
    '🏝' => 'aude øy',
    '🏘' => 'bustader',
    '🏥' => 'sjukehus',
    '🏩' => 'kjærleikshotell',
    '🏪' => 'daglegvarebutikk',
    '🏫' => 'skule',
    '💒' => 'bryllaup',
    '🗽' => 'Fridomsgudinna',
    '⛪' => 'kyrkje',
    '🌉' => 'bru om natta',
    '♨' => 'varme kjelder',
    '🚄' => 'høgfartstog',
    '🚅' => 'høgfartstog med kulenase',
    '🚍' => 'motgåande buss',
    '🚔' => 'motgåande politibil',
    '🚖' => 'motgåande taxi',
    '🚘' => 'motgåande bil',
    '🛣' => 'motorveg',
    '⛵' => 'seglbåt',
    '⛴' => 'ferje',
    '🛫' => 'fly som tek av',
    '🛬' => 'fly som landar',
    '🛸' => 'flygande tallerken',
    '⌛' => 'ferdig timeglas',
    '⏳' => 'starta timeglas',
    '⌚' => 'armbandsur',
    '⏰' => 'vekkjarklokke',
    '⏲' => 'tidtakar',
    '🕛' => 'klokka tolv',
    '🕧' => 'klokka halv eitt',
    '🕐' => 'klokka eitt',
    '🕜' => 'klokka halv to',
    '🕑' => 'klokka to',
    '🕝' => 'klokka halv tre',
    '🕒' => 'klokka tre',
    '🕞' => 'klokka halv fire',
    '🕓' => 'klokka fire',
    '🕟' => 'klokka halv fem',
    '🕔' => 'klokka fem',
    '🕠' => 'klokka halv seks',
    '🕕' => 'klokka seks',
    '🕡' => 'klokka halv sju',
    '🕖' => 'klokka sju',
    '🕢' => 'klokka halv åtte',
    '🕗' => 'klokka åtte',
    '🕣' => 'klokka halv ni',
    '🕘' => 'klokka ni',
    '🕤' => 'klokka halv ti',
    '🕙' => 'klokka ti',
    '🕥' => 'klokka halv elleve',
    '🕚' => 'klokka elleve',
    '🕦' => 'klokka halv tolv',
    '🌒' => 'veksande nymåne',
    '🌓' => 'veksande halvmåne',
    '🌔' => 'veksande fullmåne',
    '🌖' => 'avtakande fullmåne',
    '🌗' => 'avtakande halvmåne',
    '🌘' => 'avtakande nemåne',
    '🌚' => 'nymåneandlet',
    '🌛' => 'nymåne med andlet',
    '🌜' => 'nemåne med andlet',
    '🌝' => 'fullmåneandlet',
    '🌞' => 'solandlet',
    '🪐' => 'planet med ringar',
    '🌟' => 'lysande stjerne',
    '🌠' => 'stjerneskot',
    '🌌' => 'mjølkevegen',
    '🌤' => 'sol bak lita sky',
    '🌬' => 'vindandlet',
    '🌈' => 'regnboge',
    '🌂' => 'lukka paraply',
    '☔' => 'paraply med regndropar',
    '⚡' => 'høgspenning',
    '⛄' => 'snømann utan snø',
    '🔥' => 'eld',
    '💧' => 'drope',
    '🌊' => 'bølgje',
    '🎃' => 'graskarlykt',
    '🎇' => 'stjerneskot på pinne',
    '🎉' => 'smellbongbong',
    '🎎' => 'japanske dokker',
    '🎐' => 'vindspel',
    '🎑' => 'månekikkingsseremoni',
    '🧧' => 'raud konvolutt',
    '🎁' => 'gåve',
    '🎟' => 'inngangsbillettar',
    '🎣' => 'fiskestong',
    '🤿' => 'dykkarmaske',
    '🪁' => 'papirdrake',
    '🔫' => 'vasspistol',
    '🎱' => 'biljardkule',
    '🎮' => 'videospel',
    '🎰' => 'speleautomat',
    '🧩' => 'puslespelbrikke',
    '🪩' => 'spegelkule',
    '♥' => 'hjarter',
    '🀄' => 'mahjongbrikke med raud drake',
    '🎴' => 'spelkort',
    '🖼' => 'innramma bilete',
    '🎨' => 'målarpalett',
    '🥽' => 'vernebriller',
    '🧤' => 'hanskar',
    '🧦' => 'sokkar',
    '👚' => 'dameklede',
    '🪭' => 'handvifte',
    '👜' => 'handveske',
    '🛍' => 'handleposar',
    '🎒' => 'skulesekk',
    '👠' => 'høghæla sko',
    '⛑' => 'hjelm med kvit kross',
    '📿' => 'bønekrans',
    '🔇' => 'dempa høgtalar',
    '🔈' => 'høgtalar med lågt volum',
    '🔉' => 'høgtalar med middels volum',
    '🔊' => 'høgtalar med høgt volum',
    '📢' => 'høgtalar',
    '🔔' => 'bjølle',
    '🔕' => 'overstreka bjølle',
    '🎶' => 'notar',
    '🎚' => 'glidebrytar',
    '🎛' => 'kontrollbrytarar',
    '🎧' => 'hovudtelefonar',
    '🪗' => 'trekkspel',
    '📞' => 'telefonrøyr',
    '📟' => 'personsøkjar',
    '💻' => 'berbar datamaskin',
    '🖨' => 'skrivar',
    '📽' => 'filmframvisar',
    '🎬' => 'filmklappar',
    '🔍' => 'forstørringsglas mot venstre',
    '🔎' => 'forstørringsglas mot høgre',
    '🏮' => 'raud papirlykt',
    '🪔' => 'open oljelampe',
    '📕' => 'lukka bok',
    '📖' => 'open bok',
    '📗' => 'grøn bok',
    '🗞' => 'samanrulla avis',
    '💴' => 'yensetel',
    '💵' => 'dollarsetel',
    '💶' => 'eurosetel',
    '💷' => 'pundsetel',
    '💸' => 'pengar med venger',
    '💹' => 'stigande diagram med yen',
    '📨' => 'innkomande konvolutt',
    '📫' => 'lukka postkasse med flagget oppe',
    '📪' => 'lukka postkasse med flagget nede',
    '📬' => 'open postkasse med flagget oppe',
    '📭' => 'open postkasse med flagget nede',
    '🗳' => 'urne med røystesetel',
    '📂' => 'open arkivmappe',
    '🗂' => 'skiljekort',
    '📈' => 'diagram som peikar oppover',
    '📉' => 'diagram som peikar nedover',
    '🖇' => 'samanlenka binders',
    '🗑' => 'papirkorg',
    '🗝' => 'gamaldags nøkkel',
    '🔨' => 'hammar',
    '⚒' => 'hammar og hakke',
    '🛠' => 'hammar og fastnøkkel',
    '🏹' => 'pil og boge',
    '🪚' => 'handsag',
    '🪛' => 'skrutrekkjar',
    '⚖' => 'likearma skålvekt',
    '🔗' => 'lenkje',
    '🧪' => 'prøverøyr',
    '🩸' => 'bloddrope',
    '🪞' => 'spegel',
    '🪟' => 'vindauge',
    '🪠' => 'avløpsopnar',
    '🧷' => 'sikkerheitsnål',
    '🧺' => 'korg',
    '🧯' => 'brannsløkkingsapparat',
    '🚰' => 'drikkevatn',
    '🛄' => 'bagasjeband',
    '⚠' => 'åtvaring',
    '🚸' => 'barn kryssar vegen',
    '⛔' => 'ingen tilgang',
    '🚫' => 'forbode',
    '🚳' => 'syklar forbode',
    '🚭' => 'røyking forbode',
    '🚯' => 'forsøpling ikkje tillate',
    '🚱' => 'ikkje drikkevatn',
    '🚷' => 'fotgjengarar forbode',
    '📵' => 'mobiltelefon ikkje tillate',
    '☣' => 'farleg biologisk materiale',
    '↗' => 'pil opp-høgre',
    '➡' => 'pil høgre',
    '↘' => 'pil ned -høgre',
    '↔' => 'pil venstre-høgre',
    '↪' => 'pil som bøyer mot høgre',
    '🔃' => 'vertikale piler med klokka',
    '🔄' => 'piler mot klokka',
    '🛐' => 'religiøs samlingsstad',
    '☸' => 'dharmahjulet',
    '✝' => 'latinsk kross',
    '☦' => 'ortodoks kross',
    '🔯' => 'sekstagga stjerne med prikk',
    '♈' => 'Vêren',
    '♊' => 'Tvillingane',
    '♌' => 'Løva',
    '♍' => 'Jomfrua',
    '♎' => 'Vekta',
    '♐' => 'Skyttaren',
    '♒' => 'Vassmannen',
    '♓' => 'Fiskane',
    '⛎' => 'Slangeberaren',
    '🔂' => 'gjenta eitt spor-knapp',
    '▶' => 'avspelingsknapp',
    '⏯' => 'spel av / pause-knapp',
    '⏮' => 'førre spor-knapp',
    '⏺' => 'spel inn-knapp',
    '🔆' => 'mykje lys-knapp',
    '📶' => 'mobilsignal',
    '🛜' => 'trådlaust',
    '✖' => 'gonge',
    '🟰' => 'likskapsteikn i feit skrift',
    '♾' => 'uendeleg',
    '‼' => 'dobbelt utropsteikn',
    '⁉' => 'utropsteikn og spørsmålsteikn',
    '❓' => 'raudt spørsmålsteikn',
    '❔' => 'kvitt spørsmålsteikn',
    '❕' => 'kvitt utropsteikn',
    '❗' => 'raudt utropsteikn',
    '〰' => 'bølgjestrek',
    '💲' => 'dollarteikn',
    '📛' => 'namneskilt',
    '🔰' => 'japansk teikn for nybyrjar',
    '⭕' => 'tjukk raud sirkel',
    '✳' => 'asterisk med åtte spissar',
    '✴' => 'åttetagga stjerne',
    '🔠' => 'store bokstavar',
    '🔡' => 'små bokstavar',
    '🔢' => 'tal',
    '🔣' => 'symbol',
    '🈷' => '«månadleg beløp» på japansk',
    '🈶' => '«ikkje gratis» på japansk',
    '🉐' => '«spesialtilbod» på japansk',
    '🈲' => '«forbode» på japansk',
    '㊙' => '«hemmeleg» på japansk',
    '🈺' => '«open for handel» på japansk',
    '🔴' => 'raud sirkel',
    '🟢' => 'grøn sirkel',
    '⚪' => 'kvit sirkel',
    '🟥' => 'raudt kvadrat',
    '⬜' => 'stor kvit firkant',
    '◻' => 'mellomstort kvitt kvadrat',
    '◽' => 'lite/mellomstort kvitt kvadrat',
    '▫' => 'liten kvit firkant',
    '🔶' => 'stort oransje rombesymbol',
    '🔺' => 'raud trekant som peikar opp',
    '🔻' => 'raud trekant som peikar ned',
    '🔳' => 'kvit firkanta knapp',
    '🔲' => 'svart firkanta knapp',
    '🎌' => 'kryssa flagg',
    '🏳' => 'kvitt flagg',
];
